@@ -43,6 +43,8 @@ struct data_database_diagram_reader_struct {
     bool statement_diagrams_by_parent_id_null_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
     sqlite3_stmt *statement_diagrams_by_classifier_id;
     bool statement_diagrams_by_classifier_id_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
+    sqlite3_stmt *statement_diagrams_by_relationship_id;
+    bool statement_diagrams_by_relationship_id_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
     sqlite3_stmt *statement_diagram_ids_by_parent_id;
     sqlite3_stmt *statement_diagram_ids_by_parent_id_null;
     sqlite3_stmt *statement_diagram_ids_by_classifier_id;
@@ -143,6 +145,26 @@ u8_error_t data_database_diagram_reader_get_diagrams_by_classifier_id ( data_dat
                                                                         data_diagram_iterator_t *io_diagram_iterator
                                                                       );
 
+/*!
+ *  \brief reads all relationship-displaying diagrams from the database
+ *
+ *  If a relationship is scenario-specific, only the corresponding diagram is returned.
+ *  Otherwise the scenario-specific diagrams are skipped.
+ *
+ *  If a diagram shows the relationship multiple times, the diagram is returned just once (DISTINCT).
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param relationship_id id of the relationship
+ *  \param[in,out] io_diagram_iterator iterator over diagrams of selected relationship. The caller is responsible
+ *                                     for initializing before and destroying this object afterwards.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
+ *          U8_ERROR_NO_DB if the database is not open.
+ */
+u8_error_t data_database_diagram_reader_get_diagrams_by_relationship_id ( data_database_diagram_reader_t *this_,
+                                                                          data_row_t relationship_id,
+                                                                          data_diagram_iterator_t *io_diagram_iterator
+                                                                        );
+
 /*!
  *  \brief reads all child-diagram ids from the database
  *
@@ -317,7 +339,7 @@ static inline u8_error_t data_database_diagram_reader_private_bind_text_to_state
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
