@@ -83,6 +83,14 @@ void data_database_reader_db_change_callback ( data_database_reader_t *this_, da
  */
 static inline bool data_database_reader_is_open( data_database_reader_t *this_ );
 
+/*!
+ *  \brief gets the revision_id of the database
+ *
+ *  \param this_ pointer to own object attributes
+ *  \return an identifier that allows to check if the database contents has changed
+ */
+static inline data_revision_t data_database_reader_get_revision ( data_database_reader_t *this_ );
+
 /* ================================ DIAGRAM ================================ */
 
 /*!
@@ -145,6 +153,26 @@ static inline u8_error_t data_database_reader_get_diagrams_by_classifier_id ( da
                                                                               data_diagram_iterator_t *io_diagram_iterator
                                                                             );
 
+/*!
+ *  \brief reads all relationship-displaying diagrams from the database
+ *
+ *  If a relationship is scenario-specific, only the corresponding diagram is returned.
+ *  Otherwise the scenario-specific diagrams are skipped.
+ *
+ *  If a diagram shows the relationship multiple times, the diagram is returned just once (DISTINCT).
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param relationship_id id of the relationship
+ *  \param[in,out] io_diagram_iterator iterator over diagrams of selected relationship. The caller is responsible
+ *                                     for initializing before and destroying this object afterwards.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
+ *          U8_ERROR_NO_DB if the database is not open.
+ */
+static inline u8_error_t data_database_reader_get_diagrams_by_relationship_id ( data_database_reader_t *this_,
+                                                                                data_row_t relationship_id,
+                                                                                data_diagram_iterator_t *io_diagram_iterator
+                                                                              );
+
 /*!
  *  \brief reads all child-diagram ids from the database
  *
@@ -482,7 +510,7 @@ u8_error_t data_database_reader_private_close ( data_database_reader_t *this_ );
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
