@@ -72,6 +72,50 @@ static const char *const DATA_DIAGRAM_TYPE_NAME_ARRAY [DATA_DIAGRAM_TYPE_HASH_MO
         [ DATA_DIAGRAM_TYPE_UML_PROFILE_DIAGRAM ] = "Profile Diagram",
     };
 
+static const char *const DATA_DIAGRAM_TYPE_ELEMENT_KIND_ARRAY [DATA_DIAGRAM_TYPE_HASH_MOD]
+    = {
+        [ DATA_DIAGRAM_TYPE_LIST ] = "",  /* "list" */
+        [ DATA_DIAGRAM_TYPE_BOX_DIAGRAM ] = "",  /* "box" */
+        [2] = "",
+        [3] = "",
+        [ DATA_DIAGRAM_TYPE_SYSML_BLOCK_DEFINITION_DIAGRAM ] = "bdd",
+        [ DATA_DIAGRAM_TYPE_SYSML_INTERNAL_BLOCK_DIAGRAM ] = "ibd",
+        [6] = "",
+        [ DATA_DIAGRAM_TYPE_SYSML_PARAMETRIC_DIAGRAM ] = "par",  /* "parametric" */
+        [8] = "",
+        [ DATA_DIAGRAM_TYPE_SYSML_REQUIREMENTS_DIAGRAM ] = "req",  /* "requirements" */
+        [ DATA_DIAGRAM_TYPE_UML_USE_CASE_DIAGRAM ] = "uc",  /* "use case" */
+        [ DATA_DIAGRAM_TYPE_UML_ACTIVITY_DIAGRAM ] = "act",  /* "activity" */
+        [ DATA_DIAGRAM_TYPE_UML_STATE_MACHINE_DIAGRAM ] = "stm",  /* "state machine" */
+        [ DATA_DIAGRAM_TYPE_UML_SEQUENCE_DIAGRAM ] = "sd", /* "interaction" */
+        [ DATA_DIAGRAM_TYPE_UML_COMMUNICATION_DIAGRAM ] = "sd", /* "interaction" */
+        [15] = "",
+        [ DATA_DIAGRAM_TYPE_UML_TIMING_DIAGRAM ] = "sd", /* "interaction" */
+        [ DATA_DIAGRAM_TYPE_INTERACTION_OVERVIEW_DIAGRAM ] = "sd", /* "interaction" */
+        [18] = "",
+        [19] = "",
+        [20] = "",
+        [21] = "",
+        [22] = "",
+        [23] = "",
+        [24] = "",
+        [25] = "",
+        [26] = "",
+        [27] = "",
+        [28] = "",
+        [29] = "",
+        [ DATA_DIAGRAM_TYPE_UML_DEPLOYMENT_DIAGRAM ] = "dep",  /* "deployment" */
+        [ DATA_DIAGRAM_TYPE_UML_COMPONENT_DIAGRAM ] = "cmp",  /* "component" */
+        [ DATA_DIAGRAM_TYPE_UML_COMPOSITE_STRUCTURE_DIAGRAM ] = "composite",
+        [ DATA_DIAGRAM_TYPE_UML_PACKAGE_DIAGRAM ] = "pkg",  /* "package" */
+        [ DATA_DIAGRAM_TYPE_UML_CLASS_DIAGRAM ] = "class",
+        [35] = "",
+        [36] = "",
+        [37] = "",
+        [38] = "",
+        [ DATA_DIAGRAM_TYPE_UML_PROFILE_DIAGRAM ] = "profile",
+    };
+
 const char * data_diagram_type_get_name( data_diagram_type_t this_ )
 {
     const char * result
@@ -80,9 +124,17 @@ const char * data_diagram_type_get_name( data_diagram_type_t this_ )
     return ( result == NULL ) ? "" : result;
 }
 
+const char * data_diagram_type_get_element_kind( data_diagram_type_t this_ )
+{
+    const char * result
+    = ( this_ == DATA_DIAGRAM_TYPE_VOID ) ? "" : DATA_DIAGRAM_TYPE_ELEMENT_KIND_ARRAY[ this_ % DATA_DIAGRAM_TYPE_HASH_MOD ];
+    assert( result != NULL );
+    return ( result == NULL ) ? "" : result;
+}
+
 
 /*
-Copyright 2021-2025 Andreas Warnke
+Copyright 2021-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
