@@ -4,11 +4,11 @@
 
 /* const char *const DATA_HEAD_KEY_DATA_FILE_FORMAT = "DATA_FILE_FORMAT"; */
 const char *const DATA_HEAD_KEY_DATA_FILE_NAME = "DATA_FILE_NAME";
-const char *const DATA_HEAD_KEY_DATA_FILE_LAST_SYNC_CHECKSUM = "DATA_FILE_LAST_SYNC_CHECKSUM";
+const char *const DATA_HEAD_KEY_DATA_FILE_LAST_SYNC_MOD_TIME = "DATA_FILE_LAST_SYNC_MOD_TIME";
 
 
 /*
-Copyright 2023-2025 Andreas Warnke
+Copyright 2023-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
