@@ -65,6 +65,15 @@ void data_database_writer_db_change_callback ( data_database_writer_t *this_, da
     U8_TRACE_END();
 }
 
+void data_database_writer_set_revision ( data_database_writer_t *this_, data_revision_t revision )
+{
+    U8_TRACE_BEGIN();
+
+    data_database_set_revision( (*this_).database, revision );
+
+    U8_TRACE_END();
+}
+
 /* ================================ DIAGRAM ================================ */
 
 u8_error_t data_database_writer_create_diagram ( data_database_writer_t *this_,
@@ -1350,7 +1359,7 @@ u8_error_t data_database_writer_update_relationship_list_order ( data_database_w
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
