@@ -21,10 +21,13 @@ u8_error_t data_search_result_iterator_init_empty ( data_search_result_iterator_
     (*this_).is_at_classifier_end = true;
     (*this_).is_at_feature_end = true;
     (*this_).is_at_relationship_end = true;
-    (*this_).next_search_result_buf = NULL;
+    data_search_result_init_void( &((*this_).next_search_result_buf) );
 
     data_rules_init ( &((*this_).data_rules) );
 
+    (*this_).last_relationship_id = DATA_ROW_VOID;
+    (*this_).last_relationship_was_scenario = false;
+
     U8_TRACE_END_ERR(result);
     return result;
 }
@@ -33,8 +36,7 @@ u8_error_t data_search_result_iterator_reinit ( data_search_result_iterator_t *t
                                                 data_database_borrowed_stmt_t diagram_statement,
                                                 data_database_borrowed_stmt_t classifier_statement,
                                                 data_database_borrowed_stmt_t feature_statement,
-                                                data_database_borrowed_stmt_t relationship_statement,
-                                                data_search_result_t *next_search_result_buf )
+                                                data_database_borrowed_stmt_t relationship_statement )
 {
     U8_TRACE_BEGIN();
     assert( data_database_borrowed_stmt_is_valid( &diagram_statement ) );
@@ -55,7 +57,10 @@ u8_error_t data_search_result_iterator_reinit ( data_search_result_iterator_t *t
     (*this_).is_at_classifier_end = false;
     (*this_).is_at_feature_end = false;
     (*this_).is_at_relationship_end = false;
-    (*this_).next_search_result_buf = next_search_result_buf;
+    data_search_result_init_void( &((*this_).next_search_result_buf) );
+    (*this_).last_relationship_id = DATA_ROW_VOID;
+    (*this_).last_relationship_was_scenario = false;
+
     result |= data_search_result_iterator_private_step_to_next( this_ );
 
     data_rules_init ( &((*this_).data_rules) );
@@ -69,6 +74,9 @@ u8_error_t data_search_result_iterator_destroy ( data_search_result_iterator_t *
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
 
+    (*this_).last_relationship_id = DATA_ROW_VOID;
+    (*this_).last_relationship_was_scenario = false;
+
     data_rules_destroy ( &((*this_).data_rules) );
 
     result |= data_database_borrowed_stmt_destroy( &((*this_).diagram_statement) );
@@ -79,7 +87,7 @@ u8_error_t data_search_result_iterator_destroy ( data_search_result_iterator_t *
     (*this_).is_at_classifier_end = true;
     (*this_).is_at_feature_end = true;
     (*this_).is_at_relationship_end = true;
-    (*this_).next_search_result_buf = NULL;
+    data_search_result_destroy( &((*this_).next_search_result_buf) );
 
     U8_TRACE_END_ERR(result);
     return result;
@@ -87,11 +95,9 @@ u8_error_t data_search_result_iterator_destroy ( data_search_result_iterator_t *
 
 bool data_search_result_iterator_has_next ( const data_search_result_iterator_t *this_ )
 {
-    assert( NULL != (*this_).next_search_result_buf );
-
     const bool finished = (*this_).is_at_diagram_end && (*this_).is_at_classifier_end
                           && (*this_).is_at_feature_end && (*this_).is_at_relationship_end;
-    assert( ( ! finished ) == data_search_result_is_valid( (*this_).next_search_result_buf ) );
+    assert( ( ! finished ) == data_search_result_is_valid( &((*this_).next_search_result_buf) ) );
     return ( ! finished );
 }
 
@@ -103,11 +109,10 @@ u8_error_t data_search_result_iterator_next ( data_search_result_iterator_t *thi
     assert( data_database_borrowed_stmt_is_valid( &((*this_).classifier_statement) ) );
     assert( data_database_borrowed_stmt_is_valid( &((*this_).feature_statement) ) );
     assert( data_database_borrowed_stmt_is_valid( &((*this_).relationship_statement) ) );
-    assert( NULL != (*this_).next_search_result_buf );
     u8_error_t result = U8_ERROR_NONE;
 
     /* copy the next data_search_result_t to out */
-    data_search_result_copy( out_search_result, (*this_).next_search_result_buf );
+    data_search_result_copy( out_search_result, &((*this_).next_search_result_buf) );
 
     /* search (and filter) for the next valid, unfiltered search result */
     data_search_result_iterator_private_step_to_next( this_ );
@@ -126,7 +131,7 @@ u8_error_t data_search_result_iterator_private_step_to_next ( data_search_result
     u8_error_t result = U8_ERROR_NONE;
 
     /* invalidate the next_search_result_buf */
-    data_search_result_init_void( (*this_).next_search_result_buf );
+    data_search_result_init_void( &((*this_).next_search_result_buf) );
 
     if ( ! (*this_).is_at_diagram_end )
     {
@@ -144,7 +149,7 @@ u8_error_t data_search_result_iterator_private_step_to_next ( data_search_result
         {
             (*this_).is_at_diagram_end = false;
             /* read next */
-            result |= data_search_result_iterator_private_get_diagram( this_, (*this_).next_search_result_buf );
+            result |= data_search_result_iterator_private_get_diagram( this_, &((*this_).next_search_result_buf) );
         }
         else
         {
@@ -170,7 +175,7 @@ u8_error_t data_search_result_iterator_private_step_to_next ( data_search_result
         {
             (*this_).is_at_classifier_end = false;
             /* read next */
-            result |= data_search_result_iterator_private_get_classifier( this_, (*this_).next_search_result_buf );
+            result |= data_search_result_iterator_private_get_classifier( this_, &((*this_).next_search_result_buf) );
         }
         else
         {
@@ -180,7 +185,7 @@ u8_error_t data_search_result_iterator_private_step_to_next ( data_search_result
         }
     }
 
-    while ( (*this_).is_at_classifier_end && ( ! (*this_).is_at_feature_end ) && ( ! data_search_result_is_valid( (*this_).next_search_result_buf ) ) )
+    while ( (*this_).is_at_classifier_end && ( ! (*this_).is_at_feature_end ) && ( ! data_search_result_is_valid( &((*this_).next_search_result_buf) ) ) )
     {
         sqlite3_stmt *const sql_statement = data_database_borrowed_stmt_get_statement( &((*this_).feature_statement) );
 
@@ -196,7 +201,7 @@ u8_error_t data_search_result_iterator_private_step_to_next ( data_search_result
         {
             (*this_).is_at_feature_end = false;
             /* read next */
-            result |= data_search_result_iterator_private_get_feature( this_, (*this_).next_search_result_buf );
+            result |= data_search_result_iterator_private_get_feature( this_, &((*this_).next_search_result_buf) );
         }
         else
         {
@@ -206,7 +211,7 @@ u8_error_t data_search_result_iterator_private_step_to_next ( data_search_result
         }
     }
 
-    while ( (*this_).is_at_feature_end && ( ! (*this_).is_at_relationship_end ) && ( ! data_search_result_is_valid( (*this_).next_search_result_buf ) ) )
+    while ( (*this_).is_at_feature_end && ( ! (*this_).is_at_relationship_end ) && ( ! data_search_result_is_valid( &((*this_).next_search_result_buf) ) ) )
     {
         sqlite3_stmt *const sql_statement = data_database_borrowed_stmt_get_statement( &((*this_).relationship_statement) );
 
@@ -222,7 +227,7 @@ u8_error_t data_search_result_iterator_private_step_to_next ( data_search_result
         {
             (*this_).is_at_relationship_end = false;
             /* read next */
-            result |= data_search_result_iterator_private_get_relationship( this_, (*this_).next_search_result_buf );
+            result |= data_search_result_iterator_private_get_relationship( this_, &((*this_).next_search_result_buf) );
         }
         else
         {
@@ -355,7 +360,7 @@ u8_error_t data_search_result_iterator_private_get_classifier( data_search_resul
  *  note: features.key is needed for debugging only
  */
 const char *const DATA_SEARCH_RESULT_ITERATOR_SELECT_FEATURE_BY_TEXTFRAGMENT =
-"SELECT DISTINCT features.id,features.main_type,features.key,features.classifier_id,"
+"SELECT features.id,features.main_type,features.key,features.classifier_id,"
 "classifiers.main_type,diagrams.id,diagrams.diagram_type "
 "FROM features "
 "INNER JOIN classifiers ON features.classifier_id=classifiers.id "
@@ -463,6 +468,7 @@ const char *const DATA_SEARCH_RESULT_ITERATOR_SELECT_RELATIONSHIP_BY_TEXTFRAGMEN
 "SELECT DISTINCT relationships.id,relationships.main_type,relationships.name,"
 "relationships.from_classifier_id,relationships.to_classifier_id,"
 "relationships.from_feature_id,relationships.to_feature_id,"
+"source.focused_feature_id,dest.focused_feature_id,"  /* challenge: the group by clause may randomly select ids here */
 "diagrams.id,diagrams.diagram_type "
 "FROM relationships "
 "INNER JOIN diagramelements AS source "
@@ -473,7 +479,8 @@ const char *const DATA_SEARCH_RESULT_ITERATOR_SELECT_RELATIONSHIP_BY_TEXTFRAGMEN
 "WHERE relationships.name LIKE ? ESCAPE \"\\\" "
 "OR relationships.stereotype LIKE ? ESCAPE \"\\\" "
 "OR relationships.description LIKE ? ESCAPE \"\\\" "
-"GROUP BY relationships.id,diagrams.id;";  /* no duplicates if a classifier is twice in a diagram */
+//"GROUP BY relationships.id,diagrams.id "  /* good: no duplicates if a classifier is twice in a diagram / bad: randomly chosen source and dest --> use DISTINCT */
+"ORDER BY relationships.id,( (source.focused_feature_id ISNULL) AND (dest.focused_feature_id ISNULL) ) ASC;";  /* start with interactions/scenarios */
 
 /*!
  *  \brief the column id of the result where this parameter is stored: id
@@ -510,15 +517,31 @@ static const int RESULT_RELATIONSHIP_FROM_FEATURE_ID_COLUMN = 5;
  */
 static const int RESULT_RELATIONSHIP_TO_FEATURE_ID_COLUMN = 6;
 
+/*!
+ *  \brief the column id of the result where this parameter is stored: source.focused_feature_id
+ *
+ *  In case of a GROUP BY clause, this id may not be related to the RESULT_RELATIONSHIP_FROM_FEATURE_ID_COLUMN due to random selection
+ *  One may consider to remove the GROUP BY and accept more search results
+ */
+static const int RESULT_RELATIONSHIP_FROM_FOCUSED_ID_COLUMN = 7;
+
+/*!
+ *  \brief the column id of the result where this parameter is stored: dest.focused_feature_id
+ *
+ *  In case of a GROUP BY clause, this id may not be related to the RESULT_RELATIONSHIP_TO_FEATURE_ID_COLUMN due to random selection
+ *  One may consider to remove the GROUP BY and accept more search results
+ */
+static const int RESULT_RELATIONSHIP_TO_FOCUSED_ID_COLUMN = 8;
+
 /*!
  *  \brief the column id of the result where this parameter is stored: diagrams.id
  */
-static const int RESULT_RELATIONSHIP_DIAGRAM_ID_COLUMN = 7;
+static const int RESULT_RELATIONSHIP_DIAGRAM_ID_COLUMN = 9;
 
 /*!
  *  \brief the column id of the result where this parameter is stored: diagrams.diagram_type
  */
-static const int RESULT_RELATIONSHIP_DIAGRAM_TYPE_COLUMN = 8;
+static const int RESULT_RELATIONSHIP_DIAGRAM_TYPE_COLUMN = 10;
 
 u8_error_t data_search_result_iterator_private_get_relationship( data_search_result_iterator_t *this_,
                                                                  data_search_result_t *out_search_result )
@@ -528,7 +551,6 @@ u8_error_t data_search_result_iterator_private_get_relationship( data_search_res
     u8_error_t result = U8_ERROR_NONE;
 
     sqlite3_stmt *const prepared_statement = data_database_borrowed_stmt_get_statement( &((*this_).relationship_statement) );
-    unsigned int dropped_scenario_rel = 0;
 
     data_search_result_init_relationship( out_search_result,
                                           sqlite3_column_int64( prepared_statement, RESULT_RELATIONSHIP_ID_COLUMN ),
@@ -538,31 +560,81 @@ u8_error_t data_search_result_iterator_private_get_relationship( data_search_res
                                           sqlite3_column_int64( prepared_statement, RESULT_RELATIONSHIP_TO_CLASSIFIER_ID_COLUMN ),
                                           sqlite3_column_int64( prepared_statement, RESULT_RELATIONSHIP_DIAGRAM_ID_COLUMN )
                                         );
-    const data_row_t from_feat = sqlite3_column_int64( prepared_statement, RESULT_RELATIONSHIP_FROM_FEATURE_ID_COLUMN );
-    const data_row_t to_feat = sqlite3_column_int64( prepared_statement, RESULT_RELATIONSHIP_TO_FEATURE_ID_COLUMN );
+    const data_row_t from_feat
+         = ( SQLITE_NULL != sqlite3_column_type( prepared_statement, RESULT_RELATIONSHIP_FROM_FEATURE_ID_COLUMN ) )
+         ? sqlite3_column_int64( prepared_statement, RESULT_RELATIONSHIP_FROM_FEATURE_ID_COLUMN )
+         : DATA_ROW_VOID;
+         const data_row_t to_feat
+         = ( SQLITE_NULL != sqlite3_column_type( prepared_statement, RESULT_RELATIONSHIP_TO_FEATURE_ID_COLUMN ) )
+         ? sqlite3_column_int64( prepared_statement, RESULT_RELATIONSHIP_TO_FEATURE_ID_COLUMN )
+         : DATA_ROW_VOID;
+         const data_row_t from_focused
+         = ( SQLITE_NULL != sqlite3_column_type( prepared_statement, RESULT_RELATIONSHIP_FROM_FOCUSED_ID_COLUMN ) )
+         ? sqlite3_column_int64( prepared_statement, RESULT_RELATIONSHIP_FROM_FOCUSED_ID_COLUMN )
+         : DATA_ROW_VOID;
+         const data_row_t to_focused
+         = ( SQLITE_NULL != sqlite3_column_type( prepared_statement, RESULT_RELATIONSHIP_TO_FOCUSED_ID_COLUMN ) )
+         ? sqlite3_column_int64( prepared_statement, RESULT_RELATIONSHIP_TO_FOCUSED_ID_COLUMN )
+         : DATA_ROW_VOID;
     const data_diagram_type_t d_type = sqlite3_column_int( prepared_statement, RESULT_RELATIONSHIP_DIAGRAM_TYPE_COLUMN );
     U8_TRACE_INFO_INT( "- from_feat:", from_feat );
     U8_TRACE_INFO_INT( "- to_feat:", to_feat );
     U8_TRACE_INFO_INT( "- d_type:", d_type );
+    const data_row_t rel_row_id = data_id_get_row_id( data_search_result_get_match_id_const( out_search_result ) );
 
     bool filter = false;
     const bool is_scenario_diag = data_rules_diagram_is_scenario ( &((*this_).data_rules), d_type );
     /*const bool is_scenario_rel = data_rules_relationship_is_scenario_cond( &((*this_).data_rules), from_feature_type, to_feature_type);*/
     if ( is_scenario_diag )
     {
-        /* there could be valid relationships that are visible and match the search. */
-        /* but it is quite difficult to determine if the relationship is visible in the current diagram */
-        /* --> drop the result and write a not to the log */
-        dropped_scenario_rel ++;
-        filter = true;
+        /* in theory, we would need to know the from_feature_type and the to_feature_type to determine the visibility: */
+        /*
+         * const bool is_shown = data_rules_relationship_is_scenario_cond( const data_rules_t *this_,
+         *                                                                 data_feature_type_t from_feature_type,
+         *                                                                 data_feature_type_t to_feature_type
+         *                                                               );
+         */
+        /* but we only have the data_relationship_type_t and the data_diagramelement_t here and we control the order of results: */
+        const bool from_is_lifeline = ( DATA_ROW_VOID != from_feat )&&( from_focused == from_feat );
+        const bool to_is_lifeline = ( DATA_ROW_VOID != to_feat )&&( to_focused == to_feat );
+        const bool visible = from_is_lifeline && to_is_lifeline;
+        if ( visible )
+        {
+            filter = false;
+            (*this_).last_relationship_was_scenario = true;
+            (*this_).last_relationship_id = rel_row_id;
+            U8_TRACE_INFO_INT( "data_search_result_iterator: in scenario found relationship", rel_row_id );
+        }
+        else
+        {
+            filter = true;
+            U8_TRACE_INFO_INT( "data_search_result_iterator: in scenario skipped invisible relationship", rel_row_id );
+        }
     }
     else
     {
-        /* there could be hidden scenario-typed relationships in a non-scenario diagram. */
-        /* but it is quite difficult to determine if the relationship is scenario-only */
-        /* --> show the result anyway */
+        /* in theory, we would need to know the from_feature_type and the to_feature_type to determine the visibility: */
+        /*
+         * const bool is_shown = data_rules_relationship_is_scenario_cond( const data_rules_t *this_,
+         *                                                                 data_feature_type_t from_feature_type,
+         *                                                                 data_feature_type_t to_feature_type
+         *                                                               );
+         */
+        /* but we only have the data_relationship_type_t and the data_diagramelement_t here and we control the order of results: */
+        const bool is_scenario = ( (*this_).last_relationship_id == rel_row_id )&&( (*this_).last_relationship_was_scenario );
         const bool vis_by_diagram = data_rules_diagram_shows_uncond_relationships ( &((*this_).data_rules), d_type );
-        filter = ! vis_by_diagram;
+        if ( vis_by_diagram && ( ! is_scenario ) )
+        {
+            filter = false;
+            (*this_).last_relationship_was_scenario = false;
+            (*this_).last_relationship_id = rel_row_id;
+            U8_TRACE_INFO_INT( "data_search_result_iterator: non-scenario found relationship", rel_row_id );
+        }
+        else
+        {
+            filter = true;
+            U8_TRACE_INFO_INT( "data_search_result_iterator: non-scenario skipped scenario-specific relationship", rel_row_id );
+        }
     }
 
     if ( filter )
@@ -579,7 +651,7 @@ u8_error_t data_search_result_iterator_private_get_relationship( data_search_res
 
 
 /*
-Copyright 2020-2025 Andreas Warnke
+Copyright 2020-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
