@@ -25,9 +25,11 @@ test_suite_t entity_data_relationship_test_get_suite(void)
     return result;
 }
 
-#define TOO_LONG_100 "too long text ...   too long text ...   too long text ...   too long text ...   too long text ...   "
+/* initialize a long string by single characters to avoid the maximum string length ‘4095’ ISO C99 compilers are required to support */
+#define TOO_LONG_20 't', 'o', 'o', ' ', 'l', 'o', 'n', 'g', ' ', 't', 'e', 'x', 't', ' ', '.', '.', '.', ' ', ' ', ' ',
+#define TOO_LONG_100 TOO_LONG_20 TOO_LONG_20 TOO_LONG_20 TOO_LONG_20 TOO_LONG_20
 #define TOO_LONG_800 TOO_LONG_100 TOO_LONG_100 TOO_LONG_100 TOO_LONG_100 TOO_LONG_100 TOO_LONG_100 TOO_LONG_100 TOO_LONG_100
-static const char static_too_long[4801] = TOO_LONG_800 TOO_LONG_800 TOO_LONG_800 TOO_LONG_800 TOO_LONG_800 TOO_LONG_800;
+static const char static_too_long[4801] = { TOO_LONG_800 TOO_LONG_800 TOO_LONG_800 TOO_LONG_800 TOO_LONG_800 TOO_LONG_800 '\0' };
 
 struct test_fixture_struct {
     const char *too_long;  /*!< a pointer to a string that is too long */
@@ -318,7 +320,7 @@ static test_case_result_t test_set_get( test_fixture_t *test_env )
 
 
 /*
- * Copyright 2024-2025 Andreas Warnke
+ * Copyright 2024-2026 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
