@@ -28,6 +28,7 @@ struct gui_resources_struct {
 
     GdkTexture *view_new_window;
     GdkTexture *view_search;
+    GdkTexture *view_search_now;
     GdkTexture *view_navigate;
     GdkTexture *view_create;
     GdkTexture *view_edit;
@@ -56,10 +57,8 @@ struct gui_resources_struct {
     GdkTexture *navigate_create_sibling;
     GdkTexture *navigate_create_sibling_0;
     GdkTexture *navigate_open_folder;
-    GdkTexture *search_search;
-
-    GdkPixbuf *background_column;
 
+    cairo_surface_t *sketch_background;
     GdkTexture *sketch_create;
     GdkTexture *sketch_refine;
     GdkTexture *sketch_relate;
@@ -335,6 +334,13 @@ static inline GdkTexture *gui_resources_get_view_new_window ( const gui_resource
  */
 static inline GdkTexture *gui_resources_get_view_search ( const gui_resources_t *this_ );
 
+/*!
+ *  \brief gets the view_search_now
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline GdkTexture *gui_resources_get_view_search_now ( const gui_resources_t *this_ );
+
 /*!
  *  \brief gets the view_navigate
  *
@@ -413,18 +419,11 @@ static inline GdkTexture *gui_resources_get_navigate_create_sibling ( const gui_
 static inline GdkTexture *gui_resources_get_navigate_create_sibling_0 ( const gui_resources_t *this_ );
 
 /*!
- *  \brief gets the search_search
+ *  \brief gets the background as GdkPixbuf
  *
  *  \param this_ pointer to own object attributes
  */
-static inline GdkTexture *gui_resources_get_search_search ( const gui_resources_t *this_ );
-
-/*!
- *  \brief gets the background_column as GdkPixbuf
- *
- *  \param this_ pointer to own object attributes
- */
-static inline GdkPixbuf *gui_resources_get_background_column ( const gui_resources_t *this_ );
+static inline cairo_surface_t *gui_resources_get_sketch_background ( const gui_resources_t *this_ );
 
 /*!
  *  \brief gets the sketch_create as GdkTexture
@@ -1069,7 +1068,7 @@ static inline GdkTexture *gui_resources_get_type_rel_trace ( const gui_resources
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
