@@ -35,7 +35,7 @@ typedef enum pos_nav_tree_node_type_enum pos_nav_tree_node_type_t;
  */
 static inline GdkTexture * pos_nav_tree_node_type_get_icon ( pos_nav_tree_node_type_t this_,
                                                              bool highlight,
-                                                             gui_resources_t *resources
+                                                             const gui_resources_t *resources
                                                            );
 
 #include "pos_nav_tree_node_type.inl"
@@ -44,7 +44,7 @@ static inline GdkTexture * pos_nav_tree_node_type_get_icon ( pos_nav_tree_node_t
 
 
 /*
-Copyright 2021-2025 Andreas Warnke
+Copyright 2021-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
