@@ -56,7 +56,7 @@ struct gui_sketch_area_struct {
     /* external references */
     data_database_reader_t *db_reader;  /*!< pointer to external database reader */
     ctrl_controller_t *controller;  /*!< pointer to external controller */
-    gui_resources_t *resources;  /*!< pointer to external resources */
+    const gui_resources_t *resources;  /*!< pointer to external resources */
     gui_toolbox_t *toolbox;  /*!< pointer to external tool box */
     gui_search_runner_t *search_runner;  /*!< pointer to external search runner */
     gui_simple_message_to_user_t *message_to_user;  /*!< pointer to external message-displayer */
@@ -105,7 +105,7 @@ void gui_sketch_area_init ( gui_sketch_area_t *this_,
                             gui_toolbox_t *toolbox,
                             gui_search_runner_t *search_runner,
                             gui_simple_message_to_user_t *message_to_user,
-                            gui_resources_t *resources,
+                            const gui_resources_t *resources,
                             ctrl_controller_t *controller,
                             data_database_reader_t *db_reader
                           );
@@ -341,13 +341,26 @@ static inline void gui_sketch_area_private_get_element_id_at_pos ( gui_sketch_ar
                                                                    data_id_t* out_diagram_id
                                                                  );
 
+/*!
+ *  \brief gets the gui_sketch_card_t of a given diagram_id
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param diagram_id id of the diagram to find
+ *  \param[out] out_card_ptr a pointer to the searched card.
+ *  \return U8_ERROR_NONE if found, U8_ERROR_NOT_FOUND if there is no card showing the requested diagram
+ */
+static inline u8_error_t gui_sketch_area_private_get_card_of_id ( gui_sketch_area_t *this_,
+                                                                  const data_id_t* diagram_id,
+                                                                  const gui_sketch_card_t** out_card_ptr
+                                                                );
+
 #include "gui_sketch_area.inl"
 
 #endif  /* GUI_SKETCH_AREA_H */
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
