@@ -75,7 +75,7 @@ struct gui_sketch_nav_tree_struct {
     /* helper classes to perform drawing */
     gui_sketch_style_t sketch_style;
     gui_sketch_marker_t sketch_marker;
-    gui_resources_t *resources;  /*!< pointer to external resources */
+    const gui_resources_t *resources;  /*!< pointer to external resources */
     gui_sketch_texture_t *texture_downloader;  /*!< pointer to external gui_sketch_texture_t */
 };
 
@@ -89,7 +89,7 @@ typedef struct gui_sketch_nav_tree_struct gui_sketch_nav_tree_t;
  *  \param texture_downloader pointer to a gui_sketch_texture_t that can draw a texture onto a cairo drawing context
  */
 void gui_sketch_nav_tree_init ( gui_sketch_nav_tree_t *this_,
-                                gui_resources_t *resources,
+                                const gui_resources_t *resources,
                                 gui_sketch_texture_t *texture_downloader
                               );
 
@@ -109,7 +109,7 @@ void gui_sketch_nav_tree_destroy ( gui_sketch_nav_tree_t *this_ );
  *  \param diagram_id id of the diagram to load, DATA_ROW_VOID to set empty data
  *  \param db_reader pointer to a database reader object
  */
-void gui_sketch_nav_tree_load_data( gui_sketch_nav_tree_t *this_, data_row_t diagram_id, data_database_reader_t *db_reader );
+void gui_sketch_nav_tree_load_data ( gui_sketch_nav_tree_t *this_, data_row_t diagram_id, data_database_reader_t *db_reader );
 
 /*!
  *  \brief gets the id of the root diagram
@@ -179,7 +179,7 @@ void gui_sketch_nav_tree_private_layout_node ( gui_sketch_nav_tree_t *this_,
  *
  *  \param this_ pointer to own object attributes
  */
-void gui_sketch_nav_tree_invalidate_data( gui_sketch_nav_tree_t *this_ );
+void gui_sketch_nav_tree_invalidate_data ( gui_sketch_nav_tree_t *this_ );
 
 /*!
  *  \brief gets the bounds rectangle
@@ -187,7 +187,7 @@ void gui_sketch_nav_tree_invalidate_data( gui_sketch_nav_tree_t *this_ );
  *  \param this_ pointer to own object attributes
  *  \return returns the bounding box of this sketch card
  */
-static inline shape_int_rectangle_t gui_sketch_nav_tree_get_bounds( const gui_sketch_nav_tree_t *this_ );
+static inline shape_int_rectangle_t gui_sketch_nav_tree_get_bounds ( const gui_sketch_nav_tree_t *this_ );
 
 /*!
  *  \brief sets the bounds rectangle
@@ -195,7 +195,7 @@ static inline shape_int_rectangle_t gui_sketch_nav_tree_get_bounds( const gui_sk
  *  \param this_ pointer to own object attributes
  *  \param bounds bounding box of this sketch card
  */
-static inline void gui_sketch_nav_tree_set_bounds( gui_sketch_nav_tree_t *this_, shape_int_rectangle_t bounds );
+static inline void gui_sketch_nav_tree_set_bounds ( gui_sketch_nav_tree_t *this_, shape_int_rectangle_t bounds );
 
 /*!
  *  \brief gets the visible flag
@@ -203,7 +203,7 @@ static inline void gui_sketch_nav_tree_set_bounds( gui_sketch_nav_tree_t *this_,
  *  \param this_ pointer to own object attributes
  *  \return true if this sketch card is currently visible
  */
-static inline bool gui_sketch_nav_tree_is_visible( const gui_sketch_nav_tree_t *this_ );
+static inline bool gui_sketch_nav_tree_is_visible ( const gui_sketch_nav_tree_t *this_ );
 
 /*!
  *  \brief sets the visible flag
@@ -309,6 +309,20 @@ static inline const pos_nav_tree_gap_t *gui_sketch_nav_tree_get_gap_pos_const (
  */
 static inline uint32_t gui_sketch_nav_tree_get_gap_count ( const gui_sketch_nav_tree_t *this_ );
 
+/*!
+ *  \brief determines the position of a diagran node.
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param diagram_id the diagram id to be searched in the gui_sketch_nav_tree
+ *  \param[out] out_node_envelope_box the envelope box of the diagram node.
+ *                                    The envelope box encompasses the icon box and the label box of the search result.
+ *  \return DATA_ERROR_NONE if the search result exists, U8_ERROR_NOT_FOUND if there is no fitting search result on the current page
+ */
+static inline u8_error_t gui_sketch_nav_tree_get_node_envelope ( gui_sketch_nav_tree_t *this_,
+                                                                 const data_id_t* diagram_id,
+                                                                 shape_int_rectangle_t* out_node_envelope_box
+                                                               );
+
 /*!
  *  \brief draws a single diagram
  *
@@ -327,12 +341,12 @@ void gui_sketch_nav_tree_draw ( gui_sketch_nav_tree_t *this_, gui_marked_set_t *
  *  \param font_layout the pango font rendering object for i18n suppoprt
  *  \param cr the cairo drawing engine
  */
-void gui_sketch_nav_tree_private_draw_node( gui_sketch_nav_tree_t *this_,
-                                            const pos_nav_tree_node_t *node,
-                                            const gui_marked_set_t *marker,
-                                            PangoLayout *font_layout,
-                                            cairo_t *cr
-                                          );
+void gui_sketch_nav_tree_private_draw_node ( gui_sketch_nav_tree_t *this_,
+                                             const pos_nav_tree_node_t *node,
+                                             const gui_marked_set_t *marker,
+                                             PangoLayout *font_layout,
+                                             cairo_t *cr
+                                           );
 
 /*!
  *  \brief draws overlay graphics for dragging a diagram to the cairo context
@@ -341,10 +355,10 @@ void gui_sketch_nav_tree_private_draw_node( gui_sketch_nav_tree_t *this_,
  *  \param drag_state current dragging status
  *  \param cr cairo drawing context
  */
-void gui_sketch_nav_tree_draw_overlay( const gui_sketch_nav_tree_t *this_,
-                                       const gui_sketch_drag_state_t *drag_state,
-                                       cairo_t *cr
-                                     );
+void gui_sketch_nav_tree_draw_overlay ( const gui_sketch_nav_tree_t *this_,
+                                        const gui_sketch_drag_state_t *drag_state,
+                                        cairo_t *cr
+                                      );
 
 #include "gui_sketch_nav_tree.inl"
 
@@ -352,7 +366,7 @@ void gui_sketch_nav_tree_draw_overlay( const gui_sketch_nav_tree_t *this_,
 
 
 /*
-Copyright 2018-2025 Andreas Warnke
+Copyright 2018-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
