@@ -25,7 +25,7 @@ void gui_attributes_editor_init ( gui_attributes_editor_t *this_,
                                   GtkWidget *type_rel_grid,
                                   GtkTextView *description_text_view,
                                   GtkButton *commit_button,
-                                  gui_resources_t *resources,
+                                  const gui_resources_t *resources,
                                   ctrl_controller_t *controller,
                                   data_database_reader_t *db_reader,
                                   data_database_t *database,
@@ -1786,7 +1786,7 @@ void gui_attributes_editor_private_description_update_view ( gui_attributes_edit
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
