@@ -20,7 +20,7 @@ void gui_main_window_init( gui_main_window_t *this_,
                            ctrl_controller_t *controller,
                            io_data_file_t *data_file,
                            data_database_reader_t *db_reader,
-                           gui_resources_t *resources,
+                           const gui_resources_t *resources,
                            GtkApplication *gtk_app,
                            observer_t *window_close_observer,
                            observer_t *window_open_observer )
@@ -147,6 +147,7 @@ void gui_main_window_init( gui_main_window_t *this_,
     gui_file_export_dialog_init( &((*this_).file_export_dialog),
                                  io_data_file_get_database_ptr( data_file ),
                                  db_reader,
+                                 (*this_).resources,
                                  GTK_WINDOW( (*this_).window ),
                                  &((*this_).message_to_user)
                                );
@@ -396,13 +397,13 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_ )
     gui_button_init( &((*this_).file_new),
                      GDK_PAINTABLE( gui_resources_get_file_new( res ) ),
                      "new",
-                     "New"
+                     "New..."
                     );
 
     gui_button_init( &((*this_).file_open),
                      GDK_PAINTABLE( gui_resources_get_file_open( res ) ),
                      "open",
-                     "Open"
+                     "Open..."
                     );
 
     /* save icon depends if latest changes are already saved */
@@ -428,12 +429,11 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_ )
     gui_button_init( &((*this_).file_export),
                      GDK_PAINTABLE( gui_resources_get_file_export( res ) ),
                      "export",
-                     "Export"
+                     "Export..."
                     );
 
     (*this_).tool_sect_1_icon = gtk_image_new_from_paintable( GDK_PAINTABLE ( gui_resources_get_tool_sect( res ) ) );
-    gtk_widget_set_size_request( GTK_WIDGET((*this_).tool_sect_1_icon), 12 /*=w*/ , 32 /*=h*/ );
-    gtk_image_set_pixel_size( GTK_IMAGE((*this_).tool_sect_1_icon), 32 );
+    gtk_image_set_pixel_size( GTK_IMAGE((*this_).tool_sect_1_icon), 32 /*=max(w,h)*/ );
     gtk_widget_set_halign( (*this_).tool_sect_1_icon, GTK_ALIGN_START );
 
     gui_button_init( &((*this_).view_new_window),
@@ -476,8 +476,7 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_ )
                                );
 
     (*this_).tool_sect_2_icon = gtk_image_new_from_paintable( GDK_PAINTABLE ( gui_resources_get_tool_sect( res ) ) );
-    gtk_widget_set_size_request( GTK_WIDGET((*this_).tool_sect_2_icon), 12 /*=w*/ , 32 /*=h*/ );
-    gtk_image_set_pixel_size( GTK_IMAGE((*this_).tool_sect_2_icon), 32 );
+    gtk_image_set_pixel_size( GTK_IMAGE((*this_).tool_sect_2_icon), 32 /*=max(w,h)*/ );
     gtk_widget_set_halign( (*this_).tool_sect_2_icon, GTK_ALIGN_START );
 
     gui_button_init( &((*this_).edit_undo),
@@ -611,8 +610,11 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_ )
     const gui_resources_t *const res = (*this_).resources;
 
     (*this_).attr_section_icon = gtk_image_new_from_paintable( GDK_PAINTABLE ( gui_resources_get_edit_attributes_sect( res ) ) );
-    gtk_widget_set_size_request( GTK_WIDGET((*this_).attr_section_icon), 48 /*=w*/ , 12 /*=h*/ );
-    gtk_image_set_pixel_size( GTK_IMAGE((*this_).attr_section_icon), 48 );
+    gtk_widget_set_margin_start( GTK_WIDGET((*this_).attr_section_icon), 8 );
+    gtk_widget_set_margin_end( GTK_WIDGET((*this_).attr_section_icon), 8 );
+    gtk_widget_set_margin_top( GTK_WIDGET((*this_).attr_section_icon), 0 );
+    gtk_widget_set_margin_bottom( GTK_WIDGET((*this_).attr_section_icon), 0 );
+    gtk_image_set_pixel_size( GTK_IMAGE((*this_).attr_section_icon), 32 /*=max(w,h)*/ );
     gtk_widget_set_halign( (*this_).attr_section_icon, GTK_ALIGN_START );
 
     (*this_).id_label = gtk_label_new( "" );
@@ -628,7 +630,8 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_ )
     gtk_label_set_xalign( GTK_LABEL( (*this_).type_label ), 0.0 );
 
     (*this_).id_search_btn = gtk_button_new();
-    (*this_).id_search_btn_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_search_search( res ) ) );
+    (*this_).id_search_btn_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_view_search_now( res ) ) );
+    gtk_image_set_pixel_size( GTK_IMAGE((*this_).id_search_btn_icon), 32 /*=max(w,h)*/ );
     gtk_button_set_image( GTK_BUTTON((*this_).id_search_btn), (*this_).id_search_btn_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).id_search_btn), "Find Occurrences" );
     gtk_widget_set_size_request( GTK_WIDGET((*this_).id_search_btn_icon), 32 /*=w*/ , 32 /*=h*/ );
@@ -682,8 +685,7 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_ )
     "    <object class=\"GtkPaned\">\n"
     "      <property name=\"start-child\">\n"
     "        <object class=\"GtkImage\">\n"
-    "          <property name=\"width-request\">32</property>\n"
-    "          <property name=\"height-request\">24</property>\n"
+    "          <property name=\"pixel-size\">32</property>\n"
     "          <binding name=\"paintable\">\n"
     "            <lookup name=\"icon\" type=\"GuiTypeResource\">\n"
     "              <lookup name=\"item\">GtkListItem</lookup>\n"
@@ -731,7 +733,7 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_ )
 
             gui_attribute_type_of_diagram_init( &((*this_).type_diag_data[diag_idx]), diag_type, &((*this_).attributes_editor) );
             (*this_).type_diag_img[ diag_idx ] = GTK_IMAGE( gtk_image_new_from_paintable( GDK_PAINTABLE( diag_icon ) ) );
-            gtk_widget_set_size_request( GTK_WIDGET( (*this_).type_diag_img[ diag_idx ] ), 32 /*=w*/ , 24 /*=h*/ );
+            gtk_image_set_pixel_size( GTK_IMAGE((*this_).type_diag_img[ diag_idx ]), 32 /*=max(w,h)*/ );
             (*this_).type_diag_btn[ diag_idx ] = GTK_BUTTON( gtk_button_new() );
             gtk_button_set_image( (*this_).type_diag_btn[ diag_idx ], GTK_WIDGET( (*this_).type_diag_img[ diag_idx ] ) );
             gtk_widget_set_tooltip_text( GTK_WIDGET( (*this_).type_diag_btn[ diag_idx ] ), diag_name );
@@ -753,7 +755,7 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_ )
 
             gui_attribute_type_of_classifier_init( &((*this_).type_clas_data[clas_idx]), clas_type, &((*this_).attributes_editor) );
             (*this_).type_clas_img[ clas_idx ] = GTK_IMAGE( gtk_image_new_from_paintable( GDK_PAINTABLE( clas_icon ) ) );
-            gtk_widget_set_size_request( GTK_WIDGET( (*this_).type_clas_img[ clas_idx ] ), 32 /*=w*/ , 24 /*=h*/ );
+            gtk_image_set_pixel_size( GTK_IMAGE((*this_).type_clas_img[ clas_idx ]), 32 /*=max(w,h)*/ );
             (*this_).type_clas_btn[ clas_idx ] = GTK_BUTTON( gtk_button_new() );
             gtk_button_set_image( (*this_).type_clas_btn[ clas_idx ], GTK_WIDGET( (*this_).type_clas_img[ clas_idx ] ) );
             gtk_widget_set_tooltip_text( GTK_WIDGET( (*this_).type_clas_btn[ clas_idx ] ), clas_name );
@@ -775,7 +777,7 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_ )
 
             gui_attribute_type_of_feature_init( &((*this_).type_feat_data[feat_idx]), feat_type, &((*this_).attributes_editor) );
             (*this_).type_feat_img[ feat_idx ] = GTK_IMAGE( gtk_image_new_from_paintable( GDK_PAINTABLE( feat_icon ) ) );
-            gtk_widget_set_size_request( GTK_WIDGET( (*this_).type_feat_img[ feat_idx ] ), 32 /*=w*/ , 24 /*=h*/ );
+            gtk_image_set_pixel_size( GTK_IMAGE((*this_).type_feat_img[ feat_idx ]), 32 /*=max(w,h)*/ );
             (*this_).type_feat_btn[ feat_idx ] = GTK_BUTTON( gtk_button_new() );
             gtk_button_set_image( (*this_).type_feat_btn[ feat_idx ], GTK_WIDGET( (*this_).type_feat_img[ feat_idx ] ) );
             gtk_widget_set_tooltip_text( GTK_WIDGET( (*this_).type_feat_btn[ feat_idx ] ), feat_name );
@@ -797,7 +799,7 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_ )
 
             gui_attribute_type_of_relationship_init( &((*this_).type_rel_data[rel_idx]), rel_type, &((*this_).attributes_editor) );
             (*this_).type_rel_img[ rel_idx ] = GTK_IMAGE( gtk_image_new_from_paintable( GDK_PAINTABLE( rel_icon ) ) );
-            gtk_widget_set_size_request( GTK_WIDGET( (*this_).type_rel_img[ rel_idx ] ), 32 /*=w*/ , 24 /*=h*/ );
+            gtk_image_set_pixel_size( GTK_IMAGE((*this_).type_rel_img[ rel_idx ]), 32 /*=max(w,h)*/ );
             (*this_).type_rel_btn[ rel_idx ] = GTK_BUTTON( gtk_button_new() );
             gtk_button_set_image( (*this_).type_rel_btn[ rel_idx ], GTK_WIDGET( (*this_).type_rel_img[ rel_idx ] ) );
             gtk_widget_set_tooltip_text( GTK_WIDGET( (*this_).type_rel_btn[ rel_idx ] ), rel_name );
@@ -838,7 +840,12 @@ void gui_main_window_private_init_simple_message_to_user( gui_main_window_t *thi
     (*this_).message_text_label = gtk_label_new( "" );
     gtk_label_set_xalign(GTK_LABEL( (*this_).message_text_label ), 0.0 );
 
-    (*this_).message_icon_image = gtk_image_new_from_paintable( GDK_PAINTABLE ( gui_resources_get_crystal_facet_uml( res ) ) );    gtk_widget_set_size_request( GTK_WIDGET((*this_).message_icon_image), 32 /*=w*/ , 32 /*=h*/ );
+    (*this_).message_icon_image = gtk_image_new_from_paintable( GDK_PAINTABLE ( gui_resources_get_crystal_facet_uml( res ) ) );
+    gtk_image_set_pixel_size( GTK_IMAGE((*this_).message_icon_image), 32 /*=max(w,h)*/ );
+    gtk_widget_set_margin_start( GTK_WIDGET((*this_).message_icon_image), 8 );
+    gtk_widget_set_margin_end( GTK_WIDGET((*this_).message_icon_image), 8 );
+    gtk_widget_set_margin_top( GTK_WIDGET((*this_).message_icon_image), 0 );
+    gtk_widget_set_margin_bottom( GTK_WIDGET((*this_).message_icon_image), 0 );
 
     /* insert widgets to box container */
     {
@@ -869,10 +876,10 @@ void gui_main_window_private_init_search_and_sketch_area( gui_main_window_t *thi
         (*this_).search_entry = gtk_entry_new();
 
         (*this_).search_button = gtk_button_new();
-        (*this_).search_btn_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_search_search( res ) ) );
+        (*this_).search_btn_icon = gtk_image_new_from_paintable( GDK_PAINTABLE( gui_resources_get_view_search_now( res ) ) );
+        gtk_image_set_pixel_size( GTK_IMAGE((*this_).search_btn_icon), 32 /*=max(w,h)*/ );
         gtk_button_set_image( GTK_BUTTON((*this_).search_button), (*this_).search_btn_icon );
         gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).search_button), "Search" );
-        gtk_widget_set_size_request( GTK_WIDGET((*this_).search_btn_icon), 32 /*=w*/ , 32 /*=h*/ );
     }
 
     /* insert widgets to box container */
@@ -1084,6 +1091,20 @@ void gui_main_window_data_changed_callback( GtkWidget *window, data_change_messa
             U8_TRACE_INFO("icon of save button set to SAVED(/)");
         }
     }
+    else if ( DATA_CHANGE_EVENT_TYPE_REVISION_CHANGED == data_change_message_get_event( msg ) )
+    {
+        /* undo or redo caused a rewriting of the database revision */
+        const bool is_saved = io_data_file_is_in_sync( (*this_).data_file );
+        GdkPaintable *const save_icon
+            = is_saved
+            ? GDK_PAINTABLE( gui_resources_get_file_saved( (*this_).resources ) )
+            : GDK_PAINTABLE( gui_resources_get_file_save( (*this_).resources ) );
+        if ( shown_icon != save_icon )
+        {
+            gtk_image_set_from_paintable( save_image, save_icon );
+            U8_TRACE_INFO("icon of save button set to NOT-SAVED(*)");
+        }
+    }
     else if ( DATA_CHANGE_EVENT_TYPE_DB_PREPARE_CLOSE != data_change_message_get_event( msg ) )
     {
         GdkPaintable *const save_icon = GDK_PAINTABLE( gui_resources_get_file_save( (*this_).resources ) );
@@ -1135,6 +1156,18 @@ void gui_main_window_state_callback( GtkWidget* window, GtkStateFlags old_flags,
             U8_TRACE_INFO("icon of save button updated");
         }
         // U8_TRACE_FLUSH();
+
+        /* check if json file on disk was modified in the meantime */
+        const bool json_was_modified = io_data_file_is_externally_modified( (*this_).data_file );
+        if ( json_was_modified )
+        {
+            gui_simple_message_to_user_show_message_with_name( &((*this_).message_to_user),
+                                                               GUI_SIMPLE_MESSAGE_TYPE_ERROR,
+                                                               GUI_SIMPLE_MESSAGE_CONTENT_JSON_MODIFIED,
+                                                               io_data_file_get_filename_const( (*this_).data_file )
+                                                             );
+        }
+
     }
 
     U8_TRACE_TIMESTAMP();
@@ -1143,7 +1176,7 @@ void gui_main_window_state_callback( GtkWidget* window, GtkStateFlags old_flags,
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
