@@ -155,7 +155,7 @@ void gui_main_window_init( gui_main_window_t *this_,
                            ctrl_controller_t *controller,
                            io_data_file_t *data_file,
                            data_database_reader_t *db_reader,
-                           gui_resources_t *resources,
+                           const gui_resources_t *resources,
                            GtkApplication *gtk_app,
                            observer_t *window_close_observer,
                            observer_t *window_open_observer
@@ -258,7 +258,7 @@ void gui_main_window_state_callback( GtkWidget* window, GtkStateFlags old_flags,
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
