@@ -142,10 +142,10 @@ void gui_search_runner_rerun ( gui_search_runner_t *this_, pos_scroll_page_t pag
                                                         data_classifier_get_name_const( &((*this_).temp_classifier) ),
                                                         DATA_ROW_VOID /* diagram_id */
                                                       );
-                    d_err |= gui_search_runner_private_add_diagrams_of_classifier( this_,
-                                                                                   &half_initialized,
-                                                                                   &skip_results
-                                                                                 );
+                    d_err |= gui_search_runner_private_add_diagrams_of_object( this_,
+                                                                               &half_initialized,
+                                                                               &skip_results
+                                                                             );
 
                     data_classifier_destroy( &((*this_).temp_classifier) );
                     data_search_result_destroy( &half_initialized );
@@ -174,10 +174,10 @@ void gui_search_runner_rerun ( gui_search_runner_t *this_, pos_scroll_page_t pag
                                                      classifier_id,
                                                      DATA_ROW_VOID /* diagram_id */
                                                    );
-                    d_err |= gui_search_runner_private_add_diagrams_of_classifier( this_,
-                                                                                   &half_initialized,
-                                                                                   &skip_results
-                                                                                 );
+                    d_err |= gui_search_runner_private_add_diagrams_of_object( this_,
+                                                                               &half_initialized,
+                                                                               &skip_results
+                                                                             );
 
                     data_feature_destroy( &((*this_).temp_feature) );
                     data_search_result_destroy( &half_initialized );
@@ -207,10 +207,10 @@ void gui_search_runner_rerun ( gui_search_runner_t *this_, pos_scroll_page_t pag
                                                           data_relationship_get_to_classifier_row_id( &((*this_).temp_relationship) ),
                                                           DATA_ROW_VOID /* diagram_id */
                                                         );
-                    d_err |= gui_search_runner_private_add_diagrams_of_classifier( this_,
-                                                                                   &half_initialized,
-                                                                                   &skip_results
-                                                                                 );
+                    d_err |= gui_search_runner_private_add_diagrams_of_object( this_,
+                                                                               &half_initialized,
+                                                                               &skip_results
+                                                                             );
 
                     data_relationship_destroy( &((*this_).temp_relationship) );
                     data_search_result_destroy( &half_initialized );
@@ -368,80 +368,88 @@ void gui_search_runner_rerun ( gui_search_runner_t *this_, pos_scroll_page_t pag
     U8_TRACE_END();
 }
 
-u8_error_t gui_search_runner_private_add_diagrams_of_classifier( gui_search_runner_t *this_,
-                                                                 data_search_result_t *classifier_template,
-                                                                 uint_fast32_t *io_skip_results
-                                                               )
+u8_error_t gui_search_runner_private_add_diagrams_of_object( gui_search_runner_t *this_,
+                                                             data_search_result_t *result_template,
+                                                             uint_fast32_t *io_skip_results
+                                                           )
 {
     U8_TRACE_BEGIN();
-    assert( classifier_template != NULL );
+    assert( result_template != NULL );
     u8_error_t d_err = U8_ERROR_NONE;  /* a data read or data store error */
 
-    data_row_t classifier_row_id;
-    if ( DATA_TABLE_CLASSIFIER == data_id_get_table( data_search_result_get_match_id_const( classifier_template )))
-    {
-        classifier_row_id = data_id_get_row_id( data_search_result_get_match_id_const( classifier_template ));
-    }
-    else
-    {
-        classifier_row_id = data_id_get_row_id( data_search_result_get_src_classifier_id_const( classifier_template ));
-    }
-
+    /* initialize an iterator to fetch all diagrams where result_template occurs: */
     data_diagram_iterator_t diagram_iterator;
     d_err |= data_diagram_iterator_init_empty( &diagram_iterator );
-    d_err |= data_database_reader_get_diagrams_by_classifier_id( (*this_).db_reader,
-                                                                 classifier_row_id,
-                                                                 &diagram_iterator
-                                                               );
+    const data_table_t object_type = data_id_get_table( data_search_result_get_match_id_const( result_template ));
+    switch ( object_type )
+    {
+        case DATA_TABLE_CLASSIFIER:
+        {
+            const data_row_t classifier_row_id
+                = data_id_get_row_id( data_search_result_get_match_id_const( result_template ));
+            d_err |= data_database_reader_get_diagrams_by_classifier_id( (*this_).db_reader,
+                                                                         classifier_row_id,
+                                                                         &diagram_iterator
+                                                                       );
+        }
+        break;
+
+        case DATA_TABLE_FEATURE:
+        {
+            const data_row_t classifier_row_id
+                = data_id_get_row_id( data_search_result_get_src_classifier_id_const( result_template ));
+            d_err |= data_database_reader_get_diagrams_by_classifier_id( (*this_).db_reader,
+                                                                         classifier_row_id,
+                                                                         &diagram_iterator
+                                                                       );
+        }
+        break;
+
+        case DATA_TABLE_RELATIONSHIP:
+        {
+            const data_row_t relationship_row_id
+                = data_id_get_row_id( data_search_result_get_match_id_const( result_template ));
+            d_err |= data_database_reader_get_diagrams_by_relationship_id( (*this_).db_reader,
+                                                                           relationship_row_id,
+                                                                           &diagram_iterator
+                                                                         );
+        }
+        break;
+
+        default:
+        {
+            U8_LOG_ERROR_INT( "gui_search_runner_private_add_diagrams_of_object called with search result of wrong type:",
+                             object_type
+                           );
+            assert(false);
+        }
+        break;
+    }
 
     while (( data_diagram_iterator_has_next( &diagram_iterator ) )&&( d_err == U8_ERROR_NONE ))
     {
+        /* fetch diagram from iterator */
         d_err |= data_diagram_iterator_next( &diagram_iterator, &((*this_).temp_diagram) );
         const data_row_t diagram_row_id = data_diagram_get_row_id( &((*this_).temp_diagram) );
-        data_id_reinit( data_search_result_get_diagram_id_ptr( classifier_template ), DATA_TABLE_DIAGRAM, diagram_row_id );
 
-        bool filter = false;
-        switch ( data_id_get_table( data_search_result_get_match_id_const( classifier_template ) ) )
+        if ( (*io_skip_results) == 0 )
         {
-            case DATA_TABLE_FEATURE:
-            {
-                /* if a user searches explicitly for a feature-id, which feature/classifiers should be filtered? */
-                /* and how? till here, the classifier type is not yet loaded. */
-            }
-            break;
+            /* complete the half initialized search result template */
+            data_id_reinit( data_search_result_get_diagram_id_ptr( result_template ), DATA_TABLE_DIAGRAM, diagram_row_id );
 
-            case DATA_TABLE_RELATIONSHIP:
+            const u8_error_t err = data_search_result_list_add( &((*this_).result_list), result_template );
+            if ( err != U8_ERROR_NONE )
             {
-                /* if a user searches explicitly for a relationship-id, which ones should be filtered? */
-                /* and how? till here, the classifier type is not yet loaded. */
+                d_err |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
+                U8_LOG_ANOMALY( "U8_ERROR_ARRAY_BUFFER_EXCEEDED at inserting search result to list" );
+                (*this_).result_buffer_more_after = true;  /* there are more results that cannot be stored in &((*this_).result_list) */
             }
-            break;
-
-            default:
-            {
-                /* do not filter classifiers (or other things?) */
-            }
-            break;
         }
-
-        if ( ! filter )
+        else
         {
-            if ( (*io_skip_results) == 0 )
-            {
-                const u8_error_t err = data_search_result_list_add( &((*this_).result_list), classifier_template );
-                if ( err != U8_ERROR_NONE )
-                {
-                    d_err |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
-                    U8_LOG_ANOMALY( "U8_ERROR_ARRAY_BUFFER_EXCEEDED at inserting search result to list" );
-                    (*this_).result_buffer_more_after = true;  /* there are more results that cannot be stored in &((*this_).result_list) */
-                }
-            }
-            else
-            {
-                /* to advance to the requested search result page, skip this entry */
-                *io_skip_results = (*io_skip_results) - 1;
-                (*this_).result_buffer_start ++;
-            }
+            /* to advance to the requested search result page, skip this entry */
+            *io_skip_results = (*io_skip_results) - 1;
+            (*this_).result_buffer_start ++;
         }
 
         data_diagram_destroy( &((*this_).temp_diagram) );
@@ -455,7 +463,7 @@ u8_error_t gui_search_runner_private_add_diagrams_of_classifier( gui_search_runn
 
 
 /*
-Copyright 2020-2025 Andreas Warnke
+Copyright 2020-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
