@@ -10,7 +10,7 @@
 #include <stdbool.h>
 #include <assert.h>
 
-void gui_simple_message_to_user_init ( gui_simple_message_to_user_t *this_, GtkWidget *text_label, GtkWidget *icon_image, gui_resources_t *res )
+void gui_simple_message_to_user_init ( gui_simple_message_to_user_t *this_, GtkWidget *text_label, GtkWidget *icon_image, const gui_resources_t *res )
 {
     U8_TRACE_BEGIN();
     assert ( text_label != NULL );
@@ -234,6 +234,7 @@ void gui_simple_message_to_user_show_message_with_quantity ( gui_simple_message_
 }
 
 #if 0
+/* REPLACED BY gui_simple_message_to_user_show_error_info */
 void gui_simple_message_to_user_show_message_with_line ( gui_simple_message_to_user_t *this_,
                                                          gui_simple_message_type_t type_id,
                                                          const gui_simple_message_content_position_t *content_id,
@@ -336,6 +337,13 @@ void gui_simple_message_to_user_show_message_with_name ( gui_simple_message_to_u
         utf8stringbuf_append_str( &((*this_).private_temp_str), "Database file written: " );
         utf8stringbuf_append_str( &((*this_).private_temp_str), name );
     }
+    else if ( content_id == GUI_SIMPLE_MESSAGE_CONTENT_JSON_MODIFIED )
+    {
+        U8_LOG_EVENT( "GUI_SIMPLE_MESSAGE_CONTENT_JSON_MODIFIED" );
+        utf8stringbuf_append_str( &((*this_).private_temp_str), "Database file concurrently modified: " );
+        utf8stringbuf_append_str( &((*this_).private_temp_str), name );
+        utf8stringbuf_append_str( &((*this_).private_temp_str), "\nThese changes will be overwritten when saving!" );
+    }
     else
     {
         U8_LOG_ERROR("unexptected content_id");
@@ -415,7 +423,7 @@ void gui_simple_message_to_user_show_message_with_error ( gui_simple_message_to_
 }
 
 const char *const (gui_simple_message_to_user_private_table_name[DATA_STAT_TABLE_MAX])
-    = {"lifelines","classifiers","features","relations","classifier-occurrences","diagrams"};
+    = {"lifelines","classifiers","features","relationships","classifier-occurrences","diagrams"};
 const char *const (gui_simple_message_to_user_private_series_name4change[DATA_STAT_SERIES_MAX])
     = {"created","modified","deleted","ignored","warning","error"};
 const char *const (gui_simple_message_to_user_private_series_name4other[DATA_STAT_SERIES_MAX])
@@ -636,7 +644,7 @@ void gui_simple_message_to_user_hide ( gui_simple_message_to_user_t *this_ )
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
