@@ -20,7 +20,7 @@ void gui_sketch_area_init( gui_sketch_area_t *this_,
                            gui_toolbox_t *toolbox,
                            gui_search_runner_t *search_runner,
                            gui_simple_message_to_user_t *message_to_user,
-                           gui_resources_t *resources,
+                           const gui_resources_t *resources,
                            ctrl_controller_t *controller,
                            data_database_reader_t *db_reader )
 {
@@ -244,9 +244,11 @@ void gui_sketch_area_draw( gui_sketch_area_t *this_, int width, int height, cair
 
     if ( ! data_database_reader_is_open( (*this_).db_reader ) )
     {
-        shape_int_rectangle_t bounds;
-        shape_int_rectangle_init( &bounds, 0, 0, width, height );
-        gui_sketch_background_set_bounds( &((*this_).background), bounds );
+        shape_int_rectangle_t card_bounds;
+        shape_int_rectangle_init( &card_bounds, 0, 0, width, height );
+        shape_int_rectangle_t label_bounds;
+        shape_int_rectangle_init( &label_bounds, 0, 0, 0, height );
+        gui_sketch_background_set_bounds( &((*this_).background), &card_bounds, &label_bounds );
         gui_sketch_background_draw_introduction( &((*this_).background), cr );
     }
     else
@@ -545,9 +547,11 @@ void gui_sketch_area_private_layout_subwidgets ( gui_sketch_area_t *this_, shape
 
     /* layout background */
     {
-        shape_int_rectangle_t background_bounds;
-        shape_int_rectangle_init( &background_bounds, cards_left, top, cards_width, height );
-        gui_sketch_background_set_bounds( &((*this_).background), background_bounds );
+        shape_int_rectangle_t card_ground_bounds;
+        shape_int_rectangle_init( &card_ground_bounds, cards_left, top, cards_width, height );
+        shape_int_rectangle_t label_list_bounds;
+        shape_int_rectangle_init( &label_list_bounds, left, top, cards_left-left, height );
+        gui_sketch_background_set_bounds( &((*this_).background), &card_ground_bounds, &label_list_bounds );
     }
 
     U8_TRACE_END();
@@ -566,6 +570,24 @@ void gui_sketch_area_private_draw_subwidgets ( gui_sketch_area_t *this_, shape_i
         case GUI_TOOL_SEARCH:
         {
             gui_sketch_background_draw_search( &((*this_).background), cr );
+
+            /* draw link from highlighted search result to diagram */
+            const data_id_t high_obj = gui_marked_set_get_highlighted ( (*this_).marker );
+            const data_id_t high_diag = gui_marked_set_get_highlighted_diagram ( (*this_).marker );
+            shape_int_rectangle_t search_envelope_box;
+            const u8_error_t search_found
+                = gui_sketch_result_list_get_result_envelope( &((*this_).result_list),
+                                                              &high_obj,
+                                                              &high_diag,
+                                                              &search_envelope_box
+                                                            );
+            const gui_sketch_card_t* card;
+            const u8_error_t card_found = gui_sketch_area_private_get_card_of_id( this_, &high_diag, &card );
+            if (( search_found == U8_ERROR_NONE )&&( card_found == U8_ERROR_NONE ))
+            {
+                const shape_int_rectangle_t card_box = gui_sketch_card_get_bounds( card );
+                gui_sketch_background_draw_appears_link( &((*this_).background), &search_envelope_box, &card_box, cr );
+            }
         }
         break;
 
@@ -576,6 +598,19 @@ void gui_sketch_area_private_draw_subwidgets ( gui_sketch_area_t *this_, shape_i
             const unsigned int children
                 = (*this_).card_num-2;
             gui_sketch_background_draw_navigation( &((*this_).background), depth, children, cr );
+
+            /* draw link from highlighted nav_tree_node to diagram */
+            const data_id_t highlighted = gui_marked_set_get_highlighted ( (*this_).marker );
+            shape_int_rectangle_t nav_envelope_box;
+            const u8_error_t nav_found
+                = gui_sketch_nav_tree_get_node_envelope( &((*this_).nav_tree), &highlighted, &nav_envelope_box );
+            const gui_sketch_card_t* card;
+            const u8_error_t card_found = gui_sketch_area_private_get_card_of_id( this_, &highlighted, &card );
+            if (( nav_found == U8_ERROR_NONE )&&( card_found == U8_ERROR_NONE ))
+            {
+                const shape_int_rectangle_t card_box = gui_sketch_card_get_bounds( card );
+                gui_sketch_background_draw_appears_link( &((*this_).background), &nav_envelope_box, &card_box, cr );
+            }
         }
         break;
 
@@ -1936,7 +1971,7 @@ void gui_sketch_area_tool_changed_callback( GtkWidget *widget, gui_tool_t tool,
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
