@@ -7,17 +7,48 @@
 #include "gui_gtk.h"
 #include <assert.h>
 
+#if 0
+/* to convert the source file from e.g. char to int, you may uncomment this here: */
+void gui_sketch_background_private_write_as_ints( gui_sketch_background_t *this_ )
+{
+    fprintf(stdout,"%s","\n    ");
+    cairo_surface_t *bg_img = gui_resources_get_sketch_background( (*this_).resources );
+    int icon_width = cairo_image_surface_get_width( bg_img );
+    int icon_height = cairo_image_surface_get_height( bg_img );
+    unsigned char *data = cairo_image_surface_get_data( bg_img );
+    for ( int y = 0; y < icon_height; y++ )
+    {
+        for ( int x = 0; x < icon_width; x++ )
+        {
+            guchar b = data[(4*(x+(y*icon_width)))+0];
+            guchar g = data[(4*(x+(y*icon_width)))+1];
+            guchar r = data[(4*(x+(y*icon_width)))+2];
+            guchar a = data[(4*(x+(y*icon_width)))+3];
+            fprintf(stdout,"O3R(%3d,%3d,%3d,%3d), ", r, g, b, a);
+            if ( (x & 7) == 7 )
+            {
+                fprintf(stdout,"%s","\n    ");
+            }
+        }
+    }
+}
+#endif
+
 void gui_sketch_background_init( gui_sketch_background_t *this_,
-                                 gui_resources_t *resources,
+                                 const gui_resources_t *resources,
                                  gui_sketch_texture_t *texture_downloader )
 {
     U8_TRACE_BEGIN();
     assert( resources != NULL );
     assert( texture_downloader != NULL );
 
-    shape_int_rectangle_init( &((*this_).bounds), 0, 0, 0, 0 );
+    shape_int_rectangle_init( &((*this_).card_bounds), 0, 0, 0, 0 );
+    shape_int_rectangle_init( &((*this_).label_bounds), 0, 0, 0, 0 );
     (*this_).resources = resources;
     (*this_).texture_downloader = texture_downloader;
+#if 0
+    gui_sketch_background_private_write_as_ints( this_ );
+#endif
 
     U8_TRACE_END();
 }
@@ -26,7 +57,8 @@ void gui_sketch_background_destroy( gui_sketch_background_t *this_ )
 {
     U8_TRACE_BEGIN();
 
-    shape_int_rectangle_destroy( &((*this_).bounds) );
+    shape_int_rectangle_destroy( &((*this_).card_bounds) );
+    shape_int_rectangle_destroy( &((*this_).label_bounds) );
     (*this_).resources = NULL;
     (*this_).texture_downloader = NULL;
 
@@ -37,25 +69,21 @@ static const double BLACK_R = 0.0;
 static const double BLACK_G = 0.0;
 static const double BLACK_B = 0.0;
 static const double BLACK_A = 1.0;
-static const double DARK_R = 0.3;
-static const double DARK_G = 0.3;
-static const double DARK_B = 0.3;
+static const double DARK_R = 0.375;
+static const double DARK_G = 0.375;
+static const double DARK_B = 0.375;
 static const double DARK_A = 1.0;
-static const double D_GREY_R = 0.4;
-static const double D_GREY_G = 0.4;
-static const double D_GREY_B = 0.4;
-static const double D_GREY_A = 1.0;
-static const double GREY_R = 0.7;
-static const double GREY_G = 0.7;
-static const double GREY_B = 0.7;
+static const double GREY_R = 0.75;
+static const double GREY_G = 0.75;
+static const double GREY_B = 0.75;
 static const double GREY_A = 1.0;
 static const double ORANGE_R = 1.0;
-static const double ORANGE_G = 0.8;
+static const double ORANGE_G = 0.75;
 static const double ORANGE_B = 0.5;
 static const double ORANGE_A = 1.0;
-static const double LIGHT_R = 0.8;
-static const double LIGHT_G = 0.8;
-static const double LIGHT_B = 0.8;
+static const double LIGHT_R = 0.875;
+static const double LIGHT_G = 0.875;
+static const double LIGHT_B = 0.875;
 static const double LIGHT_A = 1.0;
 static const double BORDER = 8;  /* border between text/icons and ground rectangle */
 
@@ -65,35 +93,27 @@ void gui_sketch_background_draw_introduction( gui_sketch_background_t *this_,
     U8_TRACE_BEGIN();
     assert( NULL != cr );
 
-    const int32_t left = shape_int_rectangle_get_left( &((*this_).bounds) );
-    const int32_t top = shape_int_rectangle_get_top( &((*this_).bounds) );
-    const uint32_t width = shape_int_rectangle_get_width( &((*this_).bounds) );
-    const uint32_t height = shape_int_rectangle_get_height( &((*this_).bounds) );
+    const int32_t left = shape_int_rectangle_get_left( &((*this_).card_bounds) );
+    const int32_t top = shape_int_rectangle_get_top( &((*this_).card_bounds) );
+    const uint32_t width = shape_int_rectangle_get_width( &((*this_).card_bounds) );
+    const uint32_t height = shape_int_rectangle_get_height( &((*this_).card_bounds) );
 
     int32_t text_area_start;
 
     /* if there is enough space, draw a nice picture bar on the left side */
     if ( width > 192 )
     {
-        GdkPixbuf *bg_img = gui_resources_get_background_column( (*this_).resources );
-        double icon_width = gdk_pixbuf_get_width ( bg_img );
-        double icon_height = gdk_pixbuf_get_height ( bg_img );
-        gdk_cairo_set_source_pixbuf( cr, bg_img, left, top );
-        cairo_rectangle ( cr, left, top, icon_width, icon_height );
-        cairo_fill (cr);
-
-        text_area_start = left+icon_width;
-
-        if ( height > icon_height )
+        cairo_surface_t *bg_img = gui_resources_get_sketch_background( (*this_).resources );
+        int icon_width = cairo_image_surface_get_width( bg_img );
+        int icon_height = cairo_image_surface_get_height( bg_img );
+        const unsigned int tiles = (height+(icon_height-1))/icon_height;
+        for ( unsigned int tile = 0; tile < tiles; tile ++ )
         {
-            cairo_set_source_rgba( cr, 0.0, 0.4, 0.3, 1.0 );
-            cairo_rectangle ( cr, left, top+icon_height, icon_width, height-icon_height );
-            cairo_fill (cr);
-            cairo_move_to( cr, left, top+icon_height );
-            cairo_line_to( cr, left+icon_width, top+icon_height );
-            cairo_line_to( cr, left, top+icon_height-(0.3*icon_width) );
+            cairo_set_source_surface( cr, bg_img, left, top + ( tile * icon_height ) );
+            cairo_rectangle ( cr, left, top + ( tile * icon_height ), icon_width, icon_height );
             cairo_fill (cr);
         }
+        text_area_start = left+icon_width;
     }
     else
     {
@@ -149,10 +169,20 @@ void gui_sketch_background_draw_navigation( gui_sketch_background_t *this_,
     U8_TRACE_BEGIN();
     assert( NULL != cr );
 
-    const int32_t left = shape_int_rectangle_get_left( &((*this_).bounds) );
-    const int32_t top = shape_int_rectangle_get_top( &((*this_).bounds) );
-    const uint32_t width = shape_int_rectangle_get_width( &((*this_).bounds) );
-    const uint32_t height = shape_int_rectangle_get_height( &((*this_).bounds) );
+    /* draw background of nav_tree list labels */
+    const int32_t label_left = shape_int_rectangle_get_left( &((*this_).label_bounds) );
+    const int32_t label_top = shape_int_rectangle_get_top( &((*this_).label_bounds) );
+    const uint32_t label_width = shape_int_rectangle_get_width( &((*this_).label_bounds) );
+    const uint32_t label_height = shape_int_rectangle_get_height( &((*this_).label_bounds) );
+    cairo_set_source_rgba( cr, LIGHT_R, LIGHT_G, LIGHT_B, LIGHT_A );
+    cairo_rectangle ( cr, label_left, label_top, label_width, label_height );
+    cairo_fill (cr);
+
+    /* draw background of cards area */
+    const int32_t left = shape_int_rectangle_get_left( &((*this_).card_bounds) );
+    const int32_t top = shape_int_rectangle_get_top( &((*this_).card_bounds) );
+    const uint32_t width = shape_int_rectangle_get_width( &((*this_).card_bounds) );
+    const uint32_t height = shape_int_rectangle_get_height( &((*this_).card_bounds) );
 
     if ( 0 == tree_depth )
     {
@@ -160,7 +190,7 @@ void gui_sketch_background_draw_navigation( gui_sketch_background_t *this_,
     }
     else
     {
-        cairo_set_source_rgba( cr, D_GREY_R, D_GREY_G, D_GREY_B, D_GREY_A );
+        cairo_set_source_rgba( cr, DARK_R, DARK_G, DARK_B, DARK_A );
     }
     cairo_rectangle ( cr, left, top, width, height );
     cairo_fill (cr);
@@ -180,10 +210,20 @@ void gui_sketch_background_draw_search( gui_sketch_background_t *this_, cairo_t
     U8_TRACE_BEGIN();
     assert( NULL != cr );
 
-    const int32_t left = shape_int_rectangle_get_left( &((*this_).bounds) );
-    const int32_t top = shape_int_rectangle_get_top( &((*this_).bounds) );
-    const uint32_t width = shape_int_rectangle_get_width( &((*this_).bounds) );
-    const uint32_t height = shape_int_rectangle_get_height( &((*this_).bounds) );
+    /* draw background of search result list list labels */
+    const int32_t label_left = shape_int_rectangle_get_left( &((*this_).label_bounds) );
+    const int32_t label_top = shape_int_rectangle_get_top( &((*this_).label_bounds) );
+    const uint32_t label_width = shape_int_rectangle_get_width( &((*this_).label_bounds) );
+    const uint32_t label_height = shape_int_rectangle_get_height( &((*this_).label_bounds) );
+    cairo_set_source_rgba( cr, LIGHT_R, LIGHT_G, LIGHT_B, LIGHT_A );
+    cairo_rectangle ( cr, label_left, label_top, label_width, label_height );
+    cairo_fill (cr);
+
+    /* draw background of cards area */
+    const int32_t left = shape_int_rectangle_get_left( &((*this_).card_bounds) );
+    const int32_t top = shape_int_rectangle_get_top( &((*this_).card_bounds) );
+    const uint32_t width = shape_int_rectangle_get_width( &((*this_).card_bounds) );
+    const uint32_t height = shape_int_rectangle_get_height( &((*this_).card_bounds) );
 
     cairo_set_source_rgba( cr, DARK_R, DARK_G, DARK_B, DARK_A );
     cairo_rectangle ( cr, left, top, width, height );
@@ -197,10 +237,10 @@ void gui_sketch_background_draw_edit( gui_sketch_background_t *this_, cairo_t *c
     U8_TRACE_BEGIN();
     assert( NULL != cr );
 
-    const int32_t left = shape_int_rectangle_get_left( &((*this_).bounds) );
-    const int32_t top = shape_int_rectangle_get_top( &((*this_).bounds) );
-    const uint32_t width = shape_int_rectangle_get_width( &((*this_).bounds) );
-    const uint32_t height = shape_int_rectangle_get_height( &((*this_).bounds) );
+    const int32_t left = shape_int_rectangle_get_left( &((*this_).card_bounds) );
+    const int32_t top = shape_int_rectangle_get_top( &((*this_).card_bounds) );
+    const uint32_t width = shape_int_rectangle_get_width( &((*this_).card_bounds) );
+    const uint32_t height = shape_int_rectangle_get_height( &((*this_).card_bounds) );
 
     cairo_set_source_rgba( cr, DARK_R, DARK_G, DARK_B, DARK_A );
     cairo_rectangle ( cr, left, top, width, height );
@@ -214,10 +254,10 @@ void gui_sketch_background_draw_create( gui_sketch_background_t *this_, cairo_t
     U8_TRACE_BEGIN();
     assert( NULL != cr );
 
-    const int32_t left = shape_int_rectangle_get_left( &((*this_).bounds) );
-    const int32_t top = shape_int_rectangle_get_top( &((*this_).bounds) );
-    const uint32_t width = shape_int_rectangle_get_width( &((*this_).bounds) );
-    const uint32_t height = shape_int_rectangle_get_height( &((*this_).bounds) );
+    const int32_t left = shape_int_rectangle_get_left( &((*this_).card_bounds) );
+    const int32_t top = shape_int_rectangle_get_top( &((*this_).card_bounds) );
+    const uint32_t width = shape_int_rectangle_get_width( &((*this_).card_bounds) );
+    const uint32_t height = shape_int_rectangle_get_height( &((*this_).card_bounds) );
 
     cairo_set_source_rgba( cr, ORANGE_R, ORANGE_G, ORANGE_B, ORANGE_A );
     cairo_rectangle ( cr, left, top, width, height );
@@ -226,15 +266,75 @@ void gui_sketch_background_draw_create( gui_sketch_background_t *this_, cairo_t
     U8_TRACE_END();
 }
 
+void gui_sketch_background_draw_appears_link( gui_sketch_background_t *this_,
+                                              const shape_int_rectangle_t *label_box,
+                                              const shape_int_rectangle_t *card_box,
+                                              cairo_t *cr )
+{
+    U8_TRACE_BEGIN();
+    assert( NULL != label_box );
+    assert( NULL != card_box );
+    assert( NULL != cr );
+
+    const int32_t label_top = shape_int_rectangle_get_top( label_box );
+    const uint32_t label_right = shape_int_rectangle_get_right( label_box );
+    const uint32_t label_bottom = shape_int_rectangle_get_bottom( label_box );
+    const int32_t card_left = shape_int_rectangle_get_left( card_box );
+    const int32_t card_top = shape_int_rectangle_get_top( card_box );
+    const uint32_t card_right = shape_int_rectangle_get_right( card_box );
+    const uint32_t card_bottom = shape_int_rectangle_get_bottom( card_box );
+
+    cairo_set_source_rgba( cr, GREY_R, GREY_G, GREY_B, GREY_A );
+    cairo_move_to( cr, label_right, label_top );
+    if ( label_top > card_bottom )
+    {
+        const int_fast32_t big_delta_x = card_right - label_right;
+        const int_fast32_t small_delta_x = card_left - label_right;
+        const int_fast32_t big_delta_y = label_bottom - card_bottom;
+        const int_fast32_t small_delta_y = label_top - card_bottom;
+        const int_fast32_t big_mid_x = label_right + ( big_delta_x * 3 ) / 4;
+        const int_fast32_t small_mid_x = label_right + ( small_delta_x * 3 ) / 4;
+        const int_fast32_t big_mid_y = card_bottom + ( big_delta_y * 3 ) / 4;
+        const int_fast32_t small_mid_y = card_bottom + ( small_delta_y * 3 ) / 4;
+        cairo_curve_to( cr, small_mid_x, label_top, card_left, small_mid_y, card_left, card_bottom );
+        cairo_line_to( cr, card_right, card_bottom );
+        cairo_curve_to( cr, card_right, big_mid_y, big_mid_x, label_bottom, label_right, label_bottom );
+    }
+    else if ( label_bottom < card_top )
+    {
+        const int_fast32_t big_delta_x = card_right - label_right;
+        const int_fast32_t small_delta_x = card_left - label_right;
+        const int_fast32_t big_delta_y = card_top - label_top;
+        const int_fast32_t small_delta_y = card_top - label_bottom;
+        const int_fast32_t big_mid_x = label_right + ( big_delta_x * 3 ) / 4;
+        const int_fast32_t small_mid_x = label_right + ( small_delta_x * 3 ) / 4;
+        const int_fast32_t big_mid_y = card_top - ( big_delta_y * 3 ) / 4;
+        const int_fast32_t small_mid_y = card_top - ( small_delta_y * 3 ) / 4;
+        cairo_curve_to( cr, big_mid_x, label_top, card_right, big_mid_y, card_right, card_top );
+        cairo_line_to( cr, card_left, card_top );
+        cairo_curve_to( cr, card_left, small_mid_y, small_mid_x, label_bottom, label_right, label_bottom );
+    }
+    else
+    {
+        const int32_t mid_x = ( label_right + card_left ) / 2;
+        cairo_curve_to( cr, mid_x, label_top, mid_x, card_top, card_left, card_top );
+        cairo_line_to( cr, card_left, card_bottom );
+        cairo_curve_to( cr, mid_x, card_bottom, mid_x, label_bottom, label_right, label_bottom );
+    }
+    cairo_fill( cr );
+
+    U8_TRACE_END();
+}
+
 void gui_sketch_background_private_draw_quick_introduction( gui_sketch_background_t *this_, cairo_t *cr )
 {
     U8_TRACE_BEGIN();
     assert( NULL != cr );
 
-    const int32_t left = shape_int_rectangle_get_left( &((*this_).bounds) );
-    //const int32_t top = shape_int_rectangle_get_top( &((*this_).bounds) );
-    //const uint32_t width = shape_int_rectangle_get_width( &((*this_).bounds) );
-    const uint32_t height = shape_int_rectangle_get_height( &((*this_).bounds) );
+    const int32_t left = shape_int_rectangle_get_left( &((*this_).card_bounds) );
+    //const int32_t top = shape_int_rectangle_get_top( &((*this_).card_bounds) );
+    //const uint32_t width = shape_int_rectangle_get_width( &((*this_).card_bounds) );
+    const uint32_t height = shape_int_rectangle_get_height( &((*this_).card_bounds) );
 
     const int32_t TAB_HEIGHT = 144 + BORDER;
     const int32_t TAB_WIDTH = 640 + BORDER;
@@ -332,7 +432,7 @@ void gui_sketch_background_private_draw_icon_and_message( gui_sketch_background_
 
 
 /*
-Copyright 2017-2025 Andreas Warnke
+Copyright 2017-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
