@@ -6,7 +6,7 @@
 #include <assert.h>
 
 void gui_sketch_card_painter_init( gui_sketch_card_painter_t *this_,
-                                   gui_resources_t *resources,
+                                   const gui_resources_t *resources,
                                    gui_sketch_texture_t *texture_downloader )
 {
     U8_TRACE_BEGIN();
@@ -917,7 +917,7 @@ void gui_sketch_card_painter_draw_paper( gui_sketch_card_painter_t *this_,
 
 
 /*
-Copyright 2017-2025 Andreas Warnke
+Copyright 2017-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
