@@ -13,7 +13,7 @@ static const int GAP_HEIGHT = 2;
 static const int GUI_SKETCH_NAV_TREE_PANGO_AUTO_DETECT_LENGTH = -1;  /*!< pango automatically determines the string length */
 
 void gui_sketch_nav_tree_init( gui_sketch_nav_tree_t *this_,
-                               gui_resources_t *resources,
+                               const gui_resources_t *resources,
                                gui_sketch_texture_t *texture_downloader )
 {
     U8_TRACE_BEGIN();
@@ -306,7 +306,7 @@ void gui_sketch_nav_tree_do_layout( gui_sketch_nav_tree_t *this_, cairo_t *cr )
                         gui_sketch_nav_tree_private_layout_node( this_, chld_node, tree_depth+1, &y_pos, font_layout );
                     }
 
-                    prev_child_order = data_diagram_get_list_order( sibl_diag );
+                    prev_child_order = data_diagram_get_list_order( chld_diag );
                 }
 
                 /* layout lower-gap of child (if any) */
@@ -576,11 +576,6 @@ void gui_sketch_nav_tree_get_object_id_at_pos ( const gui_sketch_nav_tree_t *thi
     U8_TRACE_END();
 }
 
-static const double GREY_R = 0.8;
-static const double GREY_G = 0.8;
-static const double GREY_B = 0.8;
-static const double GREY_A = 1.0;
-
 void gui_sketch_nav_tree_draw ( gui_sketch_nav_tree_t *this_, gui_marked_set_t *marker, cairo_t *cr )
 {
     U8_TRACE_BEGIN();
@@ -596,18 +591,6 @@ void gui_sketch_nav_tree_draw ( gui_sketch_nav_tree_t *this_, gui_marked_set_t *
             pango_layout_set_font_description ( font_layout, std_font );
         }
 
-        /* draw background */
-        {
-            const int_fast32_t left = shape_int_rectangle_get_left( &((*this_).bounds) );
-            const int_fast32_t top = shape_int_rectangle_get_top( &((*this_).bounds) );
-            const uint_fast32_t width = shape_int_rectangle_get_width( &((*this_).bounds) );
-            const uint_fast32_t height = shape_int_rectangle_get_height( &((*this_).bounds) );
-
-            cairo_set_source_rgba( cr, GREY_R, GREY_G, GREY_B, GREY_A );
-            cairo_rectangle ( cr, left, top, width, height );
-            cairo_fill (cr);
-        }
-
         /* draw icons and text */
         const unsigned int count = (*this_).node_count;
         assert( count <= GUI_SKETCH_NAV_TREE_CONST_MAX_NODES );
@@ -750,7 +733,7 @@ void gui_sketch_nav_tree_draw_overlay( const gui_sketch_nav_tree_t *this_,
 
 
 /*
-Copyright 2018-2025 Andreas Warnke
+Copyright 2018-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
