@@ -13,7 +13,7 @@ static const int GUI_SKETCH_RESULT_LIST_PANGO_UNLIMITED_WIDTH = -1;
 static const int OBJ_GAP = 4;
 
 void gui_sketch_result_list_init( gui_sketch_result_list_t *this_,
-                                  gui_resources_t *resources,
+                                  const gui_resources_t *resources,
                                   gui_sketch_texture_t *texture_downloader )
 {
     U8_TRACE_BEGIN();
@@ -246,11 +246,6 @@ void gui_sketch_result_list_private_layout_element ( gui_sketch_result_list_t *t
     U8_TRACE_END();
 }
 
-static const double GREY_R = 0.8;
-static const double GREY_G = 0.8;
-static const double GREY_B = 0.8;
-static const double GREY_A = 1.0;
-
 void gui_sketch_result_list_draw ( gui_sketch_result_list_t *this_, const gui_marked_set_t *marker, cairo_t *cr )
 {
     U8_TRACE_BEGIN();
@@ -266,18 +261,6 @@ void gui_sketch_result_list_draw ( gui_sketch_result_list_t *this_, const gui_ma
             pango_layout_set_font_description ( font_layout, std_font );
         }
 
-        /* draw background */
-        {
-            const int_fast32_t left = shape_int_rectangle_get_left( &((*this_).bounds) );
-            const int_fast32_t top = shape_int_rectangle_get_top( &((*this_).bounds) );
-            const uint_fast32_t width = shape_int_rectangle_get_width( &((*this_).bounds) );
-            const uint_fast32_t height = shape_int_rectangle_get_height( &((*this_).bounds) );
-
-            cairo_set_source_rgba( cr, GREY_R, GREY_G, GREY_B, GREY_A );
-            cairo_rectangle ( cr, left, top, width, height );
-            cairo_fill (cr);
-        }
-
         /* draw icons and text */
         const uint32_t page_start = pos_search_result_page_get_page_start( &((*this_).page) );
         const uint32_t page_length = pos_search_result_page_get_page_length( &((*this_).page) );
@@ -434,7 +417,7 @@ void gui_sketch_result_list_private_draw_element( gui_sketch_result_list_t *this
 
 
 /*
-Copyright 2018-2025 Andreas Warnke
+Copyright 2018-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
