@@ -11,6 +11,7 @@
 
 #include "ctrl_controller.h"
 #include "storage/data_database.h"
+#include "storage/data_revision.h"
 #include "utf8stringbuf/utf8stringbuf.h"
 #include "u8/u8_error_info.h"
 #include "u8/u8_error.h"
@@ -34,7 +35,7 @@ struct io_data_file_struct {
                                   /*!< when flushing (sync to disk) and when closing. */
     bool delete_db_when_finished;  /*!< true if the current database (db_file_name) shall automatically */
                                    /*!< be deleted when closing. */
-    uint32_t sync_revision;  /*!< the revision id of the database that is synchronized to disk */
+    data_revision_t sync_revision;  /*!< the revision id of the database that is synchronized to disk */
 };
 
 typedef struct io_data_file_struct io_data_file_t;
@@ -58,7 +59,7 @@ void io_data_file_destroy ( io_data_file_t *this_ );
  *
  *  It is not allowed to open an already opened database.
  *
- *  Note that this function opens a database either writeable or in read-only mode if the file is read-only.
+ *  Note that this function opens a database either writeable or even in read-only mode if the file is read-only.
  *
  *  \param this_ pointer to own object attributes
  *  \param requested_file_path a relative or absolute file path
@@ -77,7 +78,7 @@ static inline u8_error_t io_data_file_open_writeable ( io_data_file_t *this_,
  *
  *  Useful for exporting data.
  *
- *  Note that this function opens even a possibly writeable file in read-only mode.
+ *  Note that this function will create (and delete later) a temporary database file nonetheless
  *
  *  \param this_ pointer to own object attributes
  *  \param requested_file_path a relative or absolute file path
@@ -96,7 +97,8 @@ static inline u8_error_t io_data_file_open_read_only ( io_data_file_t *this_,
  *
  *  It is not allowed to open an already opened database.
  *
- *  Note that this function opens a database either writeable or in read-only mode (if requested or the file is read-only)
+ *  Note that this function opens a database either writeable or in read-only mode (if requested or the file is read-only).
+ *  Note that even in read-only mode, this function will create (and delete later) a temporary database file nonetheless.
  *
  *  \param this_ pointer to own object attributes
  *  \param requested_file_path a relative or absolute file path
@@ -150,16 +152,27 @@ u8_error_t io_data_file_sync_to_disk ( io_data_file_t *this_ );
  *  \param this_ pointer to own object attributes
  *  \return revision of the database when it was last successfully synced to disk
  */
-static inline uint32_t io_data_file_get_sync_revision ( io_data_file_t *this_ );
+static inline data_revision_t io_data_file_get_sync_revision ( io_data_file_t *this_ );
 
 /*!
  *  \brief checks it the database revision equals the file revision when it was last synchronized to disk
  *
  *  \param this_ pointer to own object attributes
- *  \return true if in sync
+ *  \return true if in sync (or if the database is not open)
  */
 static inline bool io_data_file_is_in_sync ( io_data_file_t *this_ );
 
+/*!
+ *  \brief checks it the json database file was modified concurrently
+ *
+ *  This may be likely if somebody synchronized the revision control system (e.g. git)
+ *  while crystal-facet-uml had this file open.
+ *
+ *  \param this_ pointer to own object attributes
+ *  \return true if an external entitiy modified the json file in parallel
+ */
+bool io_data_file_is_externally_modified ( io_data_file_t *this_ );
+
 /*!
  *  \brief prints statistics of the current data file to the trace output
  *
@@ -253,7 +266,7 @@ u8_error_t io_data_file_private_export ( io_data_file_t *this_, const char *dst_
 
 
 /*
-Copyright 2022-2025 Andreas Warnke
+Copyright 2022-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
