@@ -273,6 +273,15 @@ static inline u8_error_t io_element_writer_assemble_diagram( io_element_writer_t
                                                              const char *diagram_file_base_name
                                                            );
 
+/*!
+ *  \brief writes the local end of a diagram and the start to descend
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param diag_ptr pointer to diagram that shall be written, not NULL
+ *  \return U8_ERROR_NONE in case of success
+ */
+static inline u8_error_t io_element_writer_descend_diagram( io_element_writer_t *this_, const data_diagram_t *diag_ptr );
+
 /*!
  *  \brief ends a diagram
  *
@@ -351,7 +360,7 @@ static inline u8_error_t io_element_writer_write_footer( io_element_writer_t *th
 
 
 /*
-Copyright 2021-2025 Andreas Warnke
+Copyright 2021-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
