@@ -52,6 +52,11 @@
 #define JSON_CONSTANTS_KEY_EDGES "edges"
 #define JSON_CONSTANTS_KEY_VIEWS "views"
 #define JSON_CONSTANTS_KEY_UUID "uuid"
+/* NEW !! */
+//#define JSON_CONSTANTS_NEW_KEYS 1
+#define JSON_CONSTANTS_KEY_TYPE_NAME "type"
+#define JSON_CONSTANTS_KEY_TYPE_ID "type_id"
+#define JSON_CONSTANTS_KEY_ORDER "order"
 
 #define JSON_CONSTANTS_KEY_DIAGRAM "diagram"
 #define JSON_CONSTANTS_KEY_DIAGRAM_ID "id"
@@ -61,7 +66,6 @@
 /* parent is the uuid of the parent diagram (if not root) */
 #define JSON_CONSTANTS_KEY_DIAGRAM_PARENT "parent"
 #define JSON_CONSTANTS_KEY_DIAGRAM_DIAGRAM_TYPE "diagram_type"
-#define JSON_CONSTANTS_KEY_DIAGRAM_DIAGRAM_TYPE_NAME "type"
 /* new in 1.43.0/1.47.0: stereotype */
 #define JSON_CONSTANTS_KEY_DIAGRAM_STEREOTYPE "stereotype"
 #define JSON_CONSTANTS_KEY_DIAGRAM_NAME "name"
@@ -70,6 +74,8 @@
 #define JSON_CONSTANTS_KEY_DIAGRAM_DISPLAY_FLAGS "display_flags"
 #define JSON_CONSTANTS_KEY_DIAGRAM_DISPLAY_FLAG_NAMES "display_tags"
 #define JSON_CONSTANTS_KEY_DIAGRAM_ELEMENTS "diagramelements"
+/* NEW !! */
+#define JSON_CONSTANTS_KEY_DIAGRAM_ELEMENT_LIST "elements"
 
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_ID "id"
 /* deprecated: diagram_id */
@@ -77,6 +83,8 @@
 /* deprecated: classifier_id */
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_CLASSIFIER_ID "classifier_id"
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_CLASSIFIER_NAME "classifier_name"
+/* NEW !! */
+#define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_NODE_NAME "node_name"
 /* deprecated: focused_feature_id */
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_FOCUSED_FEATURE_ID "focused_feature_id"
 /* unused because always empty: */
@@ -89,7 +97,6 @@
 #define JSON_CONSTANTS_KEY_CLASSIFIER "classifier"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_ID "id"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_MAIN_TYPE "main_type"
-#define JSON_CONSTANTS_KEY_CLASSIFIER_MAIN_TYPE_NAME "type"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_STEREOTYPE "stereotype"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_NAME "name"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_DESCRIPTION "description"
@@ -100,7 +107,6 @@
 
 #define JSON_CONSTANTS_KEY_FEATURE_ID "id"
 #define JSON_CONSTANTS_KEY_FEATURE_MAIN_TYPE "main_type"
-#define JSON_CONSTANTS_KEY_FEATURE_MAIN_TYPE_NAME "type"
 #define JSON_CONSTANTS_KEY_FEATURE_KEY "key"
 #define JSON_CONSTANTS_KEY_FEATURE_VALUE "value"
 #define JSON_CONSTANTS_KEY_FEATURE_DESCRIPTION "description"
@@ -125,18 +131,25 @@
 /* to_node is the uuid of either the to_classifier or (if defined) the to_feature */
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_TO_NODE "to_node"
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_MAIN_TYPE "main_type"
-#define JSON_CONSTANTS_KEY_RELATIONSHIP_MAIN_TYPE_NAME "type"
 /* new in 1.43.0/1.47.0: stereotype */
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_STEREOTYPE "stereotype"
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_NAME "name"
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_DESCRIPTION "description"
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_LIST_ORDER "list_order"
+/* NEW !! */
+#define JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_NODE_NAME "from_name"
+#define JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_PORT_NAME "from_port"
+#define JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_NODE_UUID "from"
+#define JSON_CONSTANTS_KEY_RELATIONSHIP_TO_NODE_NAME "to_name"
+#define JSON_CONSTANTS_KEY_RELATIONSHIP_TO_PORT_NAME "to_port"
+#define JSON_CONSTANTS_KEY_RELATIONSHIP_TO_NODE_UUID "to"
+
 
 #endif  /* JSON_CONSTANTS_H */
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
