@@ -287,6 +287,15 @@ u8_error_t json_element_writer_assemble_diagram( json_element_writer_t *this_,
                                                  const char *diagram_file_base_name
                                                );
 
+/*!
+ *  \brief writes the local end of a diagram and the start to descend
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param diag_ptr pointer to diagram that shall be written, not NULL
+ *  \return U8_ERROR_NONE in case of success
+ */
+u8_error_t json_element_writer_descend_diagram( json_element_writer_t *this_, const data_diagram_t *diag_ptr );
+
 /*!
  *  \brief ends a diagram
  *
@@ -373,7 +382,7 @@ u8_error_t json_element_writer_write_footer( json_element_writer_t *this_ );
 
 
 /*
-Copyright 2021-2025 Andreas Warnke
+Copyright 2021-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
