@@ -26,6 +26,7 @@
 
 #define DOCUMENT_ELEMENT_WRITER_LEFT_POINTING_GUILLEMENTS "\xc2\xab"
 #define DOCUMENT_ELEMENT_WRITER_RIGHT_POINTING_GUILLEMENTS "\xc2\xbb"
+#define DOCUMENT_ELEMENT_WRITER_NON_BREAKING_SPACE "\xc2\xa0"
 
 static const char DOCBOOK_ENC[]
     = "<?xml version=\"1.0\" encoding=\"utf-8\"?>";
@@ -66,24 +67,35 @@ static const char DOCBOOK_DIAGRAM_IMG_END[]
 static const char DOCBOOK_DIAGRAM_END[]
     = "\n</section>";
 
-static const char DOCBOOK_DESCRIPTION_START[]
+static const char DOCBOOK_CONTENT_START[]
     = "\n<para>";
+static const char DOCBOOK_CONTENT_END[]
+    = "\n</para>";
+
+static const char DOCBOOK_DESCRIPTION_START[]
+    = "\n<para role=\"description\">";
 static const char DOCBOOK_DESCRIPTION_MIDDLE[]  /* optional */
     = "\n</para>"
-      "\n<para>";
+      "\n<para role=\"description\">";
+static const char DOCBOOK_DESCRIPTION_END[]
+    = "\n</para>";
 static const char DOCBOOK_DESCRIPTION_XREF_START[]
     = "<xref linkend=\"";
 static const char DOCBOOK_DESCRIPTION_XREF_MIDDLE[]
     = "\"/>: ";
 static const char DOCBOOK_DESCRIPTION_XREF_END[]
     = "";
-static const char DOCBOOK_DESCRIPTION_END[]
-    = "\n</para>";
 
 static const char DOCBOOK_ELEMENT_LIST_START[]
     = "\n<variablelist>";
-static const char DOCBOOK_ELEMENT_START[]
-    = "\n<varlistentry>";
+static const char DOCBOOK_ELEMENT_START_DIAGRAM[]
+    = "\n<varlistentry role=\"diagram\">";
+static const char DOCBOOK_ELEMENT_START_CLASSIFIER[]
+    = "\n<varlistentry role=\"classifier\">";
+static const char DOCBOOK_ELEMENT_START_FEATURE[]
+    = "\n<varlistentry role=\"feature\">";
+static const char DOCBOOK_ELEMENT_START_RELATIONSHIP[]
+    = "\n<varlistentry role=\"relationship\">";
 static const char DOCBOOK_ELEMENT_NAME_START[]
     = "\n<term>";
 static const char DOCBOOK_ELEMENT_NAME_END[]
@@ -96,16 +108,20 @@ static const char DOCBOOK_ELEMENT_STEREO_START[]
 static const char DOCBOOK_ELEMENT_STEREO_END[]
     = DOCUMENT_ELEMENT_WRITER_RIGHT_POINTING_GUILLEMENTS;
 static const char DOCBOOK_ELEMENT_ID_START[]
-    = "\n<token>";
+    = "\n<token role=\"id\">";
 static const char DOCBOOK_ELEMENT_ID_END[]
     = "</token>";
+static const char DOCBOOK_ELEMENT_TYPE_TOKEN_START[]
+    = "\n<token role=\"type\">";
+static const char DOCBOOK_ELEMENT_TYPE_TOKEN_END[]
+    = "</token>";
 static const char DOCBOOK_ELEMENT_SEE_START[] = "\n<emphasis>(appears in ";
 static const char DOCBOOK_ELEMENT_SEE_NEXT[] = ",\n";
 static const char DOCBOOK_ELEMENT_SEE_END[] = ")\n</emphasis>";
 static const char DOCBOOK_ELEMENT_ATTRIBUTES_END[]
     = "\n</para>";
 static const char DOCBOOK_ELEMENT_DESCR_START[]  /* optional */
-    = "\n<para>";
+    = "\n<para role=\"description\">";
 static const char DOCBOOK_ELEMENT_DESCR_END[]  /* optional */
     = "\n</para>";
 static const char DOCBOOK_ELEMENT_END[]
@@ -113,6 +129,13 @@ static const char DOCBOOK_ELEMENT_END[]
       "\n</varlistentry>";
 static const char DOCBOOK_ELEMENT_LIST_END[]
     = "\n</variablelist>";
+static const char DOCBOOK_ELEMENT_DUMMY[]  /* to avoid empty lists */
+    = "\n<varlistentry role=\"dummy\"><term></term><listitem><para></para></listitem></varlistentry>";
+static const char DOCBOOK_INDENT[]
+    = "<token role=\"indent\">-<![CDATA[" DOCUMENT_ELEMENT_WRITER_NON_BREAKING_SPACE
+      DOCUMENT_ELEMENT_WRITER_NON_BREAKING_SPACE DOCUMENT_ELEMENT_WRITER_NON_BREAKING_SPACE
+      DOCUMENT_ELEMENT_WRITER_NON_BREAKING_SPACE DOCUMENT_ELEMENT_WRITER_NON_BREAKING_SPACE
+      DOCUMENT_ELEMENT_WRITER_NON_BREAKING_SPACE DOCUMENT_ELEMENT_WRITER_NON_BREAKING_SPACE "]]> </token>";
 
 /* IO_FILE_FORMAT_HTML */
 
@@ -323,6 +346,7 @@ static const struct document_element_writer_io_element_writer_if_struct document
         .end_relationship = &document_element_writer_end_relationship,
         .start_diagram = &document_element_writer_start_diagram,
         .assemble_diagram = &document_element_writer_assemble_diagram,
+        .descend_diagram = &document_element_writer_descend_diagram,
         .end_diagram = &document_element_writer_end_diagram,
         .start_diagramelement = &document_element_writer_start_diagramelement,
         .assemble_diagramelement = &document_element_writer_assemble_diagramelement,
@@ -788,9 +812,6 @@ u8_error_t document_element_writer_start_classifier( document_element_writer_t *
     {
         case IO_FILE_FORMAT_DOCBOOK:
         {
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DESCRIPTION_START );
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_LIST_START );
-            io_xml_writer_increase_indent ( &((*this_).xml_writer) );
         }
         break;
 
@@ -841,7 +862,7 @@ u8_error_t document_element_writer_assemble_classifier( document_element_writer_
     {
         case IO_FILE_FORMAT_DOCBOOK:
         {
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_START );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_START_CLASSIFIER );
             io_xml_writer_increase_indent ( &((*this_).xml_writer) );
 
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_NAME_START );
@@ -964,9 +985,6 @@ u8_error_t document_element_writer_end_classifier( document_element_writer_t *th
     {
         case IO_FILE_FORMAT_DOCBOOK:
         {
-            io_xml_writer_decrease_indent ( &((*this_).xml_writer) );
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_LIST_END );
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DESCRIPTION_END );
         }
         break;
 
@@ -1046,10 +1064,11 @@ u8_error_t document_element_writer_assemble_feature( document_element_writer_t *
     {
         case IO_FILE_FORMAT_DOCBOOK:
         {
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_START );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_START_FEATURE );
             io_xml_writer_increase_indent ( &((*this_).xml_writer) );
 
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_NAME_START );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_INDENT );
             export_err |= io_xml_writer_write_xml_enc ( &((*this_).xml_writer), feature_key );
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_NAME_END );
 
@@ -1257,15 +1276,12 @@ u8_error_t document_element_writer_assemble_relationship( document_element_write
     {
         case IO_FILE_FORMAT_DOCBOOK:
         {
-            /* list start */
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DESCRIPTION_START );
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_LIST_START );
-            io_xml_writer_increase_indent ( &((*this_).xml_writer) );
-            /* element */
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_START );
+            /* list element start */
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_START_RELATIONSHIP );
             io_xml_writer_increase_indent ( &((*this_).xml_writer) );
 
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_NAME_START );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_INDENT );
             export_err |= io_xml_writer_write_xml_enc ( &((*this_).xml_writer), relation_name );
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_NAME_END );
 
@@ -1278,7 +1294,9 @@ u8_error_t document_element_writer_assemble_relationship( document_element_write
                 export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_STEREO_END );
             }
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), TXT_SPACE );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_TYPE_TOKEN_START );
             export_err |= io_xml_writer_write_xml_enc ( &((*this_).xml_writer), relation_txticon );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_TYPE_TOKEN_END );
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), TXT_SPACE );
             export_err |= io_xml_writer_write_xml_enc ( &((*this_).xml_writer), dest_classifier_name );
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_ID_START );
@@ -1294,12 +1312,9 @@ u8_error_t document_element_writer_assemble_relationship( document_element_write
                 export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_DESCR_END );
             }
 
+            /* list element end */
             io_xml_writer_decrease_indent ( &((*this_).xml_writer) );
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_END );
-            /* list end */
-            io_xml_writer_decrease_indent ( &((*this_).xml_writer) );
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_LIST_END );
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DESCRIPTION_END );
         }
         break;
 
@@ -1480,6 +1495,9 @@ u8_error_t document_element_writer_start_diagram( document_element_writer_t *thi
         U8_LOG_ERROR( "not all bytes could be written" );
     }
 
+    /* inform the link provider on current diagram id: */
+    document_link_provider_set_current_diagram( &((*this_).link_provider), &diag_id );
+
     U8_TRACE_END_ERR( export_err );
     return export_err;
 }
@@ -1512,10 +1530,10 @@ u8_error_t document_element_writer_assemble_diagram( document_element_writer_t *
             export_err |= io_xml_writer_write_xml_enc ( &((*this_).xml_writer), diag_name );
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DIAGRAM_TITLE_END );
 
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DESCRIPTION_START );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_CONTENT_START );
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_LIST_START );
             io_xml_writer_increase_indent ( &((*this_).xml_writer) );
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_START );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_START_DIAGRAM );
             io_xml_writer_increase_indent ( &((*this_).xml_writer) );
 
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_NAME_START );
@@ -1540,7 +1558,7 @@ u8_error_t document_element_writer_assemble_diagram( document_element_writer_t *
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_END );
             io_xml_writer_decrease_indent ( &((*this_).xml_writer) );
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_LIST_END );
-            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DESCRIPTION_END );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_CONTENT_END );
 
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DESCRIPTION_START );
             export_err |= io_md_writer_transform ( &((*this_).md_writer), diag_description );
@@ -1551,6 +1569,11 @@ u8_error_t document_element_writer_assemble_diagram( document_element_writer_t *
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DIAGRAM_IMG_MIDDLE );
             export_err |= io_xml_writer_write_xml_enc ( &((*this_).xml_writer), diagram_file_base_name );
             export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_DIAGRAM_IMG_END );
+
+            /* start a para and a varlist */
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_CONTENT_START );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_LIST_START );
+            io_xml_writer_increase_indent ( &((*this_).xml_writer) );
         }
         break;
 
@@ -1630,6 +1653,48 @@ u8_error_t document_element_writer_assemble_diagram( document_element_writer_t *
     return export_err;
 }
 
+u8_error_t document_element_writer_descend_diagram( document_element_writer_t *this_, const data_diagram_t *diag_ptr )
+{
+    U8_TRACE_BEGIN();
+    assert ( NULL != diag_ptr );
+    u8_error_t export_err = U8_ERROR_NONE;
+
+    switch ( (*this_).export_type )
+    {
+        case IO_FILE_FORMAT_DOCBOOK:
+        {
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_DUMMY );
+
+            /* end a varlist and a para */
+            io_xml_writer_decrease_indent ( &((*this_).xml_writer) );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_ELEMENT_LIST_END );
+            export_err |= io_xml_writer_write_plain ( &((*this_).xml_writer), DOCBOOK_CONTENT_END );
+        }
+        break;
+
+        case IO_FILE_FORMAT_HTML:
+        {
+        }
+        break;
+
+        case IO_FILE_FORMAT_TXT:
+        {
+            /* no end diagram tags */
+        }
+        break;
+
+        default:
+        {
+            U8_LOG_ERROR("error: unknown_format.");
+            export_err = U8_ERROR_CONFIG_OUT_OF_RANGE;
+        }
+        break;
+    }
+
+    U8_TRACE_END_ERR( export_err );
+    return export_err;
+}
+
 u8_error_t document_element_writer_end_diagram( document_element_writer_t *this_, const data_diagram_t *diag_ptr )
 {
     U8_TRACE_BEGIN();
@@ -1795,7 +1860,7 @@ u8_error_t document_element_writer_write_footer( document_element_writer_t *this
 
 
 /*
-Copyright 2017-2025 Andreas Warnke
+Copyright 2017-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
