@@ -14,6 +14,7 @@
 #include "u8stream/universal_output_stream.h"
 #include "u8/u8_trace.h"
 #include "u8/u8_log.h"
+#include "u8/u8_u64.h"
 #include <assert.h>
 
 static const char *IO_DATA_FILE_TEMP_EXT = ".tmp-cfu";
@@ -36,7 +37,7 @@ void io_data_file_init ( io_data_file_t *this_ )
 
     (*this_).auto_writeback_to_json = false;
     (*this_).delete_db_when_finished = false;
-    (*this_).sync_revision = 0;
+    (*this_).sync_revision = DATA_REVISION_VOID;
 
     U8_TRACE_END();
 }
@@ -77,130 +78,199 @@ u8_error_t io_data_file_open ( io_data_file_t *this_,
     {
         if (( temp_requested )||( ! is_json ))
         {
+            U8_LOG_EVENT( "rejecting to create a new database based on a given tmp-cfu filename..." );
             U8_TRACE_INFO( "CASE: use temp db file that does not exist, is not accessible or has wrong format" );
-            U8_TRACE_INFO( read_only ? "read_only" : "writeable" );
-            /* This is a strange request, but we can create such an sqlite file. */
-            /* To be consistent with the case of opening an existing temporary file, also this is exported to json later */
-            (*this_).auto_writeback_to_json = ( ! read_only );
-            (*this_).delete_db_when_finished = ( ! read_only );
+            /* This request happens when the user selected the .tmp-fcu file of an already open database. */
+            /* When the database has been closed, the .tmp-cfu file vanishes and now cannot be found anymore. */
+            (*this_).auto_writeback_to_json = false;
+            (*this_).delete_db_when_finished = false;
 
             err |= utf8stringbuf_copy_view( &((*this_).data_file_name), &req_file_parent );
             err |= utf8stringbuf_append_view( &((*this_).data_file_name), &req_file_basename );
             err |= utf8stringbuf_append_str( &((*this_).data_file_name), IO_DATA_FILE_JSON_EXT );
 
             err |= utf8stringbuf_copy_str( &((*this_).db_file_name), requested_file_path );
+
+            U8_TRACE_INFO_STR( "data_file_name:", utf8stringbuf_get_string( &((*this_).data_file_name) ) );
+            U8_TRACE_INFO_STR( "db_file_name:  ", utf8stringbuf_get_string( &((*this_).db_file_name) ) );
+
+            /* do not open a non-existing .tmp-cfu file */
+            err = U8_ERROR_FILE_ALREADY_REMOVED;
+
+            /* new file is not in sync by definition */
+            (*this_).sync_revision = DATA_REVISION_VOID;
         }
         else
         {
+            U8_LOG_EVENT( "creating a new database based on a given json filename (cfuJ)..." );
             U8_TRACE_INFO( "CASE: use json file that does not exist or is not accessible" );
-            U8_TRACE_INFO( read_only ? "read_only" : "writeable" );
             /* A new json file shall be created */
-            (*this_).auto_writeback_to_json = ( ! read_only );
-            (*this_).delete_db_when_finished = ( ! read_only );
+            (*this_).auto_writeback_to_json = true;
+            (*this_).delete_db_when_finished = true;
             err |= utf8stringbuf_copy_str( &((*this_).data_file_name), requested_file_path );
+
             err |= utf8stringbuf_copy_view( &((*this_).db_file_name), &req_file_parent );
             err |= utf8stringbuf_append_view( &((*this_).db_file_name), &req_file_basename );
             err |= utf8stringbuf_append_str( &((*this_).db_file_name), IO_DATA_FILE_TEMP_EXT );
             u8dir_file_remove( utf8stringbuf_get_string( &((*this_).db_file_name) ) );  /* ignore possible errors */
+
+            U8_TRACE_INFO_STR( "data_file_name:", utf8stringbuf_get_string( &((*this_).data_file_name) ) );
+            U8_TRACE_INFO_STR( "db_file_name:  ", utf8stringbuf_get_string( &((*this_).db_file_name) ) );
+
+            err |= data_database_open( &((*this_).database), utf8stringbuf_get_string( &((*this_).db_file_name) ) );
+
+            /* new file is not in sync by definition */
+            (*this_).sync_revision = DATA_REVISION_VOID;
         }
     }
     else
     {
         if ( temp_requested )
         {
-            U8_TRACE_INFO_STR( "CASE: use existing temp file", read_only ? "read_only" : "writeable" );
+            U8_LOG_EVENT( "opening an existing database based on a given tmp-cfu filename..." );
+            U8_TRACE_INFO( "CASE: use existing temp file" );
             /* A temporary sqlite file shall be used and later be exported to json */
-            (*this_).auto_writeback_to_json = ( ! read_only );
-            (*this_).delete_db_when_finished = ( ! read_only );
+            (*this_).auto_writeback_to_json = true;
+            (*this_).delete_db_when_finished = true;
             err |= utf8stringbuf_copy_view( &((*this_).data_file_name), &req_file_parent );
             err |= utf8stringbuf_append_view( &((*this_).data_file_name), &req_file_basename );
             err |= utf8stringbuf_append_str( &((*this_).data_file_name), IO_DATA_FILE_JSON_EXT );
+
             err |= utf8stringbuf_copy_str( &((*this_).db_file_name), requested_file_path );
+
+            U8_TRACE_INFO_STR( "data_file_name:", utf8stringbuf_get_string( &((*this_).data_file_name) ) );
+            U8_TRACE_INFO_STR( "db_file_name:  ", utf8stringbuf_get_string( &((*this_).db_file_name) ) );
+
+            err |= data_database_open( &((*this_).database), utf8stringbuf_get_string( &((*this_).db_file_name) ) );
+
+            /* temp file is not in sync by definition */
+            (*this_).sync_revision = DATA_REVISION_VOID;
+
+            /* Reading the DATA_HEAD_KEY_DATA_FILE_NAME from the just opened (*this_).db_file_name */
+            /* If found, update (*this_).data_file_name */
+            if ( err == U8_ERROR_NONE )
+            {
+                data_database_head_t head_table;
+                data_database_head_init( &head_table, &((*this_).database) );
+
+                data_head_t head;
+                u8_error_t key_err = data_database_head_read_value_by_key( &head_table, DATA_HEAD_KEY_DATA_FILE_NAME, &head );
+                if ( key_err == U8_ERROR_NONE )
+                {
+                    /* case: recovery after abnormal program termination */
+                    U8_TRACE_INFO_STR( "data_file_name (updated):", data_head_get_value_const( &head ) );
+                    /* set the data_file_name to the read head value */
+                    err |= utf8stringbuf_copy_view( &((*this_).data_file_name), &req_file_parent );
+                    err |= utf8stringbuf_append_str( &((*this_).data_file_name), data_head_get_value_const( &head ) );
+                }
+
+                data_database_head_destroy( &head_table );
+            }
         }
         else if ( is_json )
         {
-            U8_TRACE_INFO_STR( "CASE: use existing json file", read_only ? "read_only" : "writeable" );
+            U8_LOG_EVENT( "opening an existing database based on a given json filename (cfuJ)..." );
+            U8_TRACE_INFO_STR( "CASE: use existing json file ", read_only ? "read_only" : "writeable" );
             /* An existing json file shall be used */
             (*this_).auto_writeback_to_json = ( ! read_only );
             (*this_).delete_db_when_finished = true;
             err |= utf8stringbuf_copy_str( &((*this_).data_file_name), requested_file_path );
+
             err |= utf8stringbuf_copy_view( &((*this_).db_file_name), &req_file_parent );
             err |= utf8stringbuf_append_view( &((*this_).db_file_name), &req_file_basename );
             err |= utf8stringbuf_append_str( &((*this_).db_file_name), IO_DATA_FILE_TEMP_EXT );
             u8dir_file_remove( utf8stringbuf_get_string( &((*this_).db_file_name) ) );  /* ignore possible errors */
 
+            U8_TRACE_INFO_STR( "data_file_name:", utf8stringbuf_get_string( &((*this_).data_file_name) ) );
+            U8_TRACE_INFO_STR( "db_file_name:  ", utf8stringbuf_get_string( &((*this_).db_file_name) ) );
+
             err |= data_database_open( &((*this_).database), utf8stringbuf_get_string( &((*this_).db_file_name) ) );
             if ( err != U8_ERROR_NONE )
             {
                 U8_LOG_ERROR("An error occurred at creating a temporary database file, possibly the parent directory is read-only.")
                 U8_LOG_WARNING("Changes will not be written back to not accidentally overwrite the data source")
                 (*this_).auto_writeback_to_json = false;
-                (*this_).delete_db_when_finished = true;  /* do not keep .tmp-cfu files when import was not successful */
+                (*this_).delete_db_when_finished = true;  /* do not keep .tmp-cfu file, it was not successfully created anyhow */
+
+                /* temp file is not in sync because import not possible */
+                (*this_).sync_revision = DATA_REVISION_VOID;
             }
             else
             {
+                /* import */
                 err |= io_data_file_private_import( this_, utf8stringbuf_get_string( &((*this_).data_file_name) ), out_err_info );
-                err |= data_database_close( &((*this_).database) );
 
                 if ( err != U8_ERROR_NONE )
                 {
+                    err |= data_database_close( &((*this_).database) );
+
                     U8_LOG_ERROR("An error occurred at reading a json data file")
                     u8dir_file_remove( utf8stringbuf_get_string( &((*this_).db_file_name) ) );  /* ignore possible additional errors */
                     U8_LOG_WARNING("Changes will not be written back to not accidentally overwrite the data source")
                     (*this_).auto_writeback_to_json = false;
-                    (*this_).delete_db_when_finished = true;  /* do not keep .tmp-cfu files when import was not successful */
+                    (*this_).delete_db_when_finished = false;  /* .tmp-cfu file was just deleted */
+                    /* file is not in sync with closed db */
+                    (*this_).sync_revision = DATA_REVISION_VOID;
+                }
+                else
+                {
+                    (*this_).sync_revision = data_database_get_revision( &((*this_).database) );
+                    U8_TRACE_INFO_INT( "sync_revision", (*this_).sync_revision );
+
+                    /* update head data */
+                    data_database_head_t head_table;
+                    data_database_head_init( &head_table, &((*this_).database) );
+                    {
+                        /* DATA_HEAD_KEY_DATA_FILE_NAME */
+                        data_head_t head1;
+                        const char *const requested_file_name = utf8stringview_get_start( &req_file_name );  /* This view is null terminated */
+                        data_head_init_new( &head1, DATA_HEAD_KEY_DATA_FILE_NAME, requested_file_name );
+                        err |= data_database_head_create_value( &head_table, &head1, NULL );
+                        data_head_destroy( &head1 );
+                        U8_TRACE_INFO_STR( "io_data_file_open/DATA_FILE_NAME", requested_file_name );
+
+                        /* DATA_HEAD_KEY_DATA_FILE_LAST_SYNC_MOD_TIME */
+                        uint64_t mod_time;
+                        u8_error_t mtime_err = u8dir_file_get_modification_time( requested_file_path, &mod_time );
+                        if ( mtime_err == U8_ERROR_NONE )
+                        {
+                            u8_u64_hex_t hex_time;
+                            u8_u64_get_hex( mod_time, &hex_time );
+                            data_head_t head2;
+                            data_head_init_new( &head2, DATA_HEAD_KEY_DATA_FILE_LAST_SYNC_MOD_TIME, &(hex_time[0]) );
+                            err |= data_database_head_create_value( &head_table, &head2, NULL );
+                            data_head_destroy( &head2 );
+                            U8_TRACE_INFO_STR( "io_data_file_open/DATA_FILE_LAST_SYNC_MOD_TIME", &(hex_time[0]) );
+                        }
+                    }
+                    data_database_head_destroy( &head_table );
+
+                    /* restore revision to the one that is stored in the undo redo list */
+                    data_database_set_revision( &((*this_).database), (*this_).sync_revision );
                 }
             }
         }
         else
         {
-            U8_TRACE_INFO_STR( "CASE: use existing sqlite file", read_only ? "read_only" : "writeable" );
-            /* An sqlite file shall be used */
-            (*this_).auto_writeback_to_json = false;
-            (*this_).delete_db_when_finished = false;
-            err |= utf8stringbuf_copy_str( &((*this_).data_file_name), requested_file_path );
-            err |= utf8stringbuf_copy_str( &((*this_).db_file_name), requested_file_path );
-        }
-    }
-    U8_TRACE_INFO_STR( "data_file_name:", utf8stringbuf_get_string( &((*this_).data_file_name) ) );
-    U8_TRACE_INFO_STR( "db_file_name:  ", utf8stringbuf_get_string( &((*this_).db_file_name) ) );
-
-    if ( err == U8_ERROR_NONE )
-    {
-        if ( read_only )
-        {
-            err |= data_database_open_read_only( &((*this_).database), utf8stringbuf_get_string( &((*this_).db_file_name) ) );
-        }
-        else
-        {
-            err |= data_database_open( &((*this_).database), utf8stringbuf_get_string( &((*this_).db_file_name) ) );
-        }
-    }
-
-    /* Reading the DATA_HEAD_KEY_DATA_FILE_NAME from the just opened (*this_).db_file_name */
-    /* If found, update (*this_).data_file_name; otherwise if there is a json-writeback file, store the name */
-    if ( err == U8_ERROR_NONE )
-    {
-        data_database_head_t head_table;
-        data_database_head_init( &head_table, &((*this_).database) );
-        data_head_t head;
-        u8_error_t key_err = data_database_head_read_value_by_key( &head_table, DATA_HEAD_KEY_DATA_FILE_NAME, &head );
-        if ( key_err == U8_ERROR_NONE )
-        {
-            U8_TRACE_INFO_STR( "DATA_FILE_NAME:", data_head_get_value_const( &head ) );
-            /* set the data_file_name to the read head value */
+            U8_LOG_EVENT( "opening an existing database based on an old sqlite3 filename (cfu1)..." );
+            U8_TRACE_INFO( "CASE: use existing sqlite file, auto-convert it to json" );
+            /* An old sqlite file shall be used, this is automatically converted to json */
+            (*this_).auto_writeback_to_json = true;
+            (*this_).delete_db_when_finished = true;
             err |= utf8stringbuf_copy_view( &((*this_).data_file_name), &req_file_parent );
-            err |= utf8stringbuf_append_str( &((*this_).data_file_name), data_head_get_value_const( &head ) );
-        }
-        else if ( (*this_).auto_writeback_to_json )
-        {
-            const char *const requested_file_name = utf8stringview_get_start( &req_file_name );  /* This view is null terminated */
-            data_head_init_new( &head, DATA_HEAD_KEY_DATA_FILE_NAME, requested_file_name );
-            err |= data_database_head_create_value( &head_table, &head, NULL );
-        }
-        data_database_head_destroy( &head_table );
+            err |= utf8stringbuf_append_view( &((*this_).data_file_name), &req_file_basename );
+            err |= utf8stringbuf_append_str( &((*this_).data_file_name), IO_DATA_FILE_JSON_EXT );
 
-        (*this_).sync_revision = data_database_get_revision( &((*this_).database) );
+            err |= utf8stringbuf_copy_str( &((*this_).db_file_name), requested_file_path );
+
+            U8_TRACE_INFO_STR( "data_file_name:", utf8stringbuf_get_string( &((*this_).data_file_name) ) );
+            U8_TRACE_INFO_STR( "db_file_name:  ", utf8stringbuf_get_string( &((*this_).db_file_name) ) );
+
+            err |= data_database_open( &((*this_).database), utf8stringbuf_get_string( &((*this_).db_file_name) ) );
+
+            /* old file is not in sync to force conversion to json */
+            (*this_).sync_revision = DATA_REVISION_VOID;
+        }
     }
 
     U8_TRACE_END_ERR( err );
@@ -213,7 +283,7 @@ u8_error_t io_data_file_close ( io_data_file_t *this_ )
 
     u8_error_t result = U8_ERROR_NONE;
 
-    if ( (*this_).auto_writeback_to_json )
+    if ( (*this_).auto_writeback_to_json && ( ! io_data_file_is_in_sync( this_ ) ) )
     {
         U8_TRACE_INFO( "CASE: auto_writeback_to_json == true" );
         result |= io_data_file_private_export( this_, utf8stringbuf_get_string( &((*this_).data_file_name) ) );
@@ -240,15 +310,85 @@ u8_error_t io_data_file_sync_to_disk ( io_data_file_t *this_ )
 
     u8_error_t result = data_database_flush_caches( &((*this_).database) );
 
-    if ( (*this_).auto_writeback_to_json )
+    if ( (*this_).auto_writeback_to_json )  /* ignore if already in_sync - if explicitly requested, simply do sync (again) */
     {
         result |= io_data_file_private_export( this_, utf8stringbuf_get_string( &((*this_).data_file_name) ) );
     }
 
+    /* get sync revision */
+    (*this_).sync_revision = data_database_get_revision( &((*this_).database) );
+    U8_TRACE_INFO_INT( "sync_revision", (*this_).sync_revision );
+
+    /* update head data */
+    data_database_head_t head_table;
+    data_database_head_init( &head_table, &((*this_).database) );
+    {
+        /* DATA_HEAD_KEY_DATA_FILE_LAST_SYNC_MOD_TIME */
+        uint64_t mod_time;
+        const char *const json_file_path = utf8stringbuf_get_string( &((*this_).data_file_name) );
+        u8_error_t mtime_err = u8dir_file_get_modification_time( json_file_path, &mod_time );
+        if ( mtime_err == U8_ERROR_NONE )
+        {
+            u8_u64_hex_t hex_time;
+            u8_u64_get_hex( mod_time, &hex_time );
+            result |= data_database_head_update_value_by_key( &head_table,
+                                                              DATA_HEAD_KEY_DATA_FILE_LAST_SYNC_MOD_TIME,
+                                                              &(hex_time[0]),
+                                                              true,
+                                                              NULL
+                                                            );
+            U8_TRACE_INFO_STR( "io_data_file_sync_to_disk/DATA_FILE_LAST_SYNC_MOD_TIME", &(hex_time[0]) );
+        }
+    }
+    data_database_head_destroy( &head_table );
+
+    /* restore sync revision so that undo_redo history and this_ refer to the same revision */
+    data_database_set_revision( &((*this_).database), (*this_).sync_revision );
+
     U8_TRACE_END_ERR( result );
     return result;
 }
 
+bool io_data_file_is_externally_modified ( io_data_file_t *this_ )
+{
+    U8_TRACE_BEGIN();
+    bool result = false;
+
+    if ( data_database_is_open( &((*this_).database) ) )
+    {
+        data_database_head_t head_table;
+        data_database_head_init( &head_table, &((*this_).database) );
+        {
+            uint64_t mod_time;
+            const char *const json_file_path = utf8stringbuf_get_string( &((*this_).data_file_name) );
+            u8_error_t mtime_err = u8dir_file_get_modification_time( json_file_path, &mod_time );
+            if ( mtime_err == U8_ERROR_NONE )
+            {
+                u8_u64_hex_t hex_time;
+                u8_u64_get_hex( mod_time, &hex_time );
+
+                data_head_t head_val;
+                const u8_error_t db_err
+                    = data_database_head_read_value_by_key( &head_table,
+                                                            DATA_HEAD_KEY_DATA_FILE_LAST_SYNC_MOD_TIME,
+                                                            &head_val
+                                                        );
+                if ( db_err == U8_ERROR_NONE )
+                {
+                    if ( ! utf8string_equals_str( &(hex_time[0]), data_head_get_value_const( &head_val ) ) )
+                    {
+                        result = true;
+                    }
+                }
+            }
+        }
+        data_database_head_destroy( &head_table );
+    }
+
+    U8_TRACE_END();
+    return result;
+}
+
 u8_error_t io_data_file_trace_stats ( io_data_file_t *this_ )
 {
     U8_TRACE_BEGIN();
@@ -372,8 +512,6 @@ u8_error_t io_data_file_private_export ( io_data_file_t *this_, const char *dst_
         }
         io_exporter_destroy( &exporter );
         data_database_reader_destroy( &db_reader );
-
-        (*this_).sync_revision = data_database_get_revision( &((*this_).database) );
     }
     else
     {
@@ -386,7 +524,7 @@ u8_error_t io_data_file_private_export ( io_data_file_t *this_, const char *dst_
 
 
 /*
-Copyright 2022-2025 Andreas Warnke
+Copyright 2022-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
