@@ -38,6 +38,7 @@ static const struct json_element_writer_io_element_writer_if_struct json_element
         .end_relationship = &json_element_writer_end_relationship,
         .start_diagram = &json_element_writer_start_diagram,
         .assemble_diagram = &json_element_writer_assemble_diagram,
+        .descend_diagram = &json_element_writer_descend_diagram,
         .end_diagram = &json_element_writer_end_diagram_fake,
         .start_diagramelement = &json_element_writer_start_diagramelement,
         .assemble_diagramelement = &json_element_writer_assemble_diagramelement,
@@ -131,9 +132,14 @@ u8_error_t json_element_writer_write_header( json_element_writer_t *this_, const
     /* two of these 6-byte sequences may form a surrogate pair */
     out_err |= json_writer_write_member_string( &((*this_).json_writer), 2, "structure_format", "rfc-8259 w/o hexadecimal escapes", true );
     out_err |= json_writer_write_member_string( &((*this_).json_writer), 2, "format", "cfu-json", true );
+#ifdef JSON_CONSTANTS_NEW_KEYS
+    out_err |= json_writer_write_member_int( &((*this_).json_writer), 2, "major_version", 2, true );
+    out_err |= json_writer_write_member_int( &((*this_).json_writer), 2, "minor_version", 0, true );
+#else
     /* version 1.1 stores stereotypes for diagrams and relationships */
     out_err |= json_writer_write_member_int( &((*this_).json_writer), 2, "major_version", 1, true );
-    out_err |= json_writer_write_member_int( &((*this_).json_writer), 2, "minor_version", 2, true );
+    out_err |= json_writer_write_member_int( &((*this_).json_writer), 2, "minor_version", 3, true );
+#endif
     out_err |= json_writer_write_member_string( &((*this_).json_writer), 2, "generator_name", META_INFO_PROGRAM_ID_STR, true );
     out_err |= json_writer_write_member_string( &((*this_).json_writer), 2, "generator_version", META_VERSION_STR, false );
 
@@ -304,9 +310,13 @@ u8_error_t json_element_writer_assemble_classifier( json_element_writer_t *this_
                                                     );
         out_err |= json_writer_write_member_enum( &((*this_).json_writer),
                                                   4,
-                                                  JSON_CONSTANTS_KEY_CLASSIFIER_MAIN_TYPE_NAME,
+                                                  JSON_CONSTANTS_KEY_TYPE_NAME,
                                                   type_name,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                  JSON_CONSTANTS_KEY_TYPE_ID,
+#else
                                                   JSON_CONSTANTS_KEY_CLASSIFIER_MAIN_TYPE,
+#endif
                                                   data_classifier_get_main_type( classifier_ptr ),
                                                   true
                                                 );
@@ -357,7 +367,11 @@ u8_error_t json_element_writer_assemble_classifier( json_element_writer_t *this_
         /* list_order */
         out_err |= json_writer_write_member_int( &((*this_).json_writer),
                                                  4,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                 JSON_CONSTANTS_KEY_ORDER,
+#else
                                                  JSON_CONSTANTS_KEY_CLASSIFIER_LIST_ORDER,
+#endif
                                                  data_classifier_get_list_order( classifier_ptr ),
                                                  true
                                                );
@@ -516,9 +530,13 @@ u8_error_t json_element_writer_assemble_feature( json_element_writer_t *this_,
                                                  );
         out_err |= json_writer_write_member_enum( &((*this_).json_writer),
                                                   6,
-                                                  JSON_CONSTANTS_KEY_FEATURE_MAIN_TYPE_NAME,
+                                                  JSON_CONSTANTS_KEY_TYPE_NAME,
                                                   type_name,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                  JSON_CONSTANTS_KEY_TYPE_ID,
+#else
                                                   JSON_CONSTANTS_KEY_FEATURE_MAIN_TYPE,
+#endif
                                                   data_feature_get_main_type( feature_ptr ),
                                                   true
                                                 );
@@ -553,7 +571,11 @@ u8_error_t json_element_writer_assemble_feature( json_element_writer_t *this_,
         /* list_order */
         out_err |= json_writer_write_member_int( &((*this_).json_writer),
                                                  6,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                 JSON_CONSTANTS_KEY_ORDER,
+#else
                                                  JSON_CONSTANTS_KEY_FEATURE_LIST_ORDER,
+#endif
                                                  data_feature_get_list_order( feature_ptr ),
                                                  true
                                                );
@@ -692,9 +714,13 @@ u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *thi
                                                       );
         out_err |= json_writer_write_member_enum( &((*this_).json_writer),
                                                   4,
-                                                  JSON_CONSTANTS_KEY_RELATIONSHIP_MAIN_TYPE_NAME,
+                                                  JSON_CONSTANTS_KEY_TYPE_NAME,
                                                   type_name,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                  JSON_CONSTANTS_KEY_TYPE_ID,
+#else
                                                   JSON_CONSTANTS_KEY_RELATIONSHIP_MAIN_TYPE,
+#endif
                                                   data_relationship_get_main_type( relation_ptr ),
                                                   true
                                                 );
@@ -729,7 +755,11 @@ u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *thi
         /* list_order */
         out_err |= json_writer_write_member_int( &((*this_).json_writer),
                                                  4,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                 JSON_CONSTANTS_KEY_ORDER,
+#else
                                                  JSON_CONSTANTS_KEY_RELATIONSHIP_LIST_ORDER,
+#endif
                                                  data_relationship_get_list_order( relation_ptr ),
                                                  true
                                                );
@@ -742,7 +772,11 @@ u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *thi
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_QUOTE
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                            JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_NODE_NAME
+#else
                                             JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_CLASSIFIER_NAME
+#endif
                                             JSON_CONSTANTS_QUOTE
                                             JSON_CONSTANTS_DEF
                                             JSON_CONSTANTS_QUOTE
@@ -762,7 +796,11 @@ u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *thi
                                                 JSON_CONSTANTS_TAB
                                                 JSON_CONSTANTS_TAB
                                                 JSON_CONSTANTS_QUOTE
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_PORT_NAME
+#else
                                                 JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_FEATURE_KEY
+#endif
                                                 JSON_CONSTANTS_QUOTE
                                                 JSON_CONSTANTS_DEF
                                                 JSON_CONSTANTS_QUOTE
@@ -776,6 +814,24 @@ u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *thi
                                               );
         }
 
+        /* from node ref_uuid */
+        const char *const from_node_ref
+            = ( from_f_valid )
+            ? data_feature_get_uuid_const( from_f )
+            : ( from_c_valid )
+            ? data_classifier_get_uuid_const( from_c )
+            : "";
+        out_err |= json_writer_write_member_string( &((*this_).json_writer),
+                                                    4,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                    JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_NODE_UUID,
+#else
+                                                    JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_NODE,
+#endif
+                                                    from_node_ref,
+                                                    true
+                                                  );
+
         /* to_classifier_name */
         const char *const to_c_name = to_c_valid ? data_classifier_get_name_const( to_c ) : "";
         out_err |= json_writer_write_plain( &((*this_).json_writer),
@@ -784,7 +840,11 @@ u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *thi
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_QUOTE
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                            JSON_CONSTANTS_KEY_RELATIONSHIP_TO_NODE_NAME
+#else
                                             JSON_CONSTANTS_KEY_RELATIONSHIP_TO_CLASSIFIER_NAME
+#endif
                                             JSON_CONSTANTS_QUOTE
                                             JSON_CONSTANTS_DEF
                                             JSON_CONSTANTS_QUOTE
@@ -804,7 +864,11 @@ u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *thi
                                                 JSON_CONSTANTS_TAB
                                                 JSON_CONSTANTS_TAB
                                                 JSON_CONSTANTS_QUOTE
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                JSON_CONSTANTS_KEY_RELATIONSHIP_TO_PORT_NAME
+#else
                                                 JSON_CONSTANTS_KEY_RELATIONSHIP_TO_FEATURE_KEY
+#endif
                                                 JSON_CONSTANTS_QUOTE
                                                 JSON_CONSTANTS_DEF
                                                 JSON_CONSTANTS_QUOTE
@@ -818,20 +882,6 @@ u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *thi
                                               );
         }
 
-        /* from node ref_uuid */
-        const char *const from_node_ref
-            = ( from_f_valid )
-            ? data_feature_get_uuid_const( from_f )
-            : ( from_c_valid )
-            ? data_classifier_get_uuid_const( from_c )
-            : "";
-        out_err |= json_writer_write_member_string( &((*this_).json_writer),
-                                                    4,
-                                                    JSON_CONSTANTS_KEY_RELATIONSHIP_FROM_NODE,
-                                                    from_node_ref,
-                                                    true
-                                                  );
-
         /* to node ref_uuid */
         const char *const to_node_ref
             = ( to_f_valid )
@@ -841,7 +891,11 @@ u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *thi
             : "";
         out_err |= json_writer_write_member_string( &((*this_).json_writer),
                                                     4,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                    JSON_CONSTANTS_KEY_RELATIONSHIP_TO_NODE_UUID,
+#else
                                                     JSON_CONSTANTS_KEY_RELATIONSHIP_TO_NODE,
+#endif
                                                     to_node_ref,
                                                     true
                                                   );
@@ -966,9 +1020,13 @@ u8_error_t json_element_writer_assemble_diagram( json_element_writer_t *this_,
                                                  );
         out_err |= json_writer_write_member_enum( &((*this_).json_writer),
                                                   4,
-                                                  JSON_CONSTANTS_KEY_DIAGRAM_DIAGRAM_TYPE_NAME,
+                                                  JSON_CONSTANTS_KEY_TYPE_NAME,
                                                   type_name,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                  JSON_CONSTANTS_KEY_TYPE_ID,
+#else
                                                   JSON_CONSTANTS_KEY_DIAGRAM_DIAGRAM_TYPE,
+#endif
                                                   data_diagram_get_diagram_type( diag_ptr ),
                                                   true
                                                 );
@@ -1003,7 +1061,11 @@ u8_error_t json_element_writer_assemble_diagram( json_element_writer_t *this_,
         /* list_order */
         out_err |= json_writer_write_member_int( &((*this_).json_writer),
                                                  4,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                 JSON_CONSTANTS_KEY_ORDER,
+#else
                                                  JSON_CONSTANTS_KEY_DIAGRAM_LIST_ORDER,
+#endif
                                                  data_diagram_get_list_order( diag_ptr ),
                                                  true
                                                );
@@ -1065,7 +1127,11 @@ u8_error_t json_element_writer_assemble_diagram( json_element_writer_t *this_,
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_TAB
                                             JSON_CONSTANTS_QUOTE
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                            JSON_CONSTANTS_KEY_DIAGRAM_ELEMENT_LIST
+#else
                                             JSON_CONSTANTS_KEY_DIAGRAM_ELEMENTS
+#endif
                                             JSON_CONSTANTS_QUOTE
                                             JSON_CONSTANTS_DEF_NL
                                             JSON_CONSTANTS_TAB
@@ -1086,6 +1152,16 @@ u8_error_t json_element_writer_assemble_diagram( json_element_writer_t *this_,
     return out_err;
 }
 
+u8_error_t json_element_writer_descend_diagram( json_element_writer_t *this_, const data_diagram_t *diag_ptr )
+{
+  U8_TRACE_BEGIN();
+  assert( diag_ptr != NULL );
+  u8_error_t out_err = U8_ERROR_NONE;
+
+  U8_TRACE_END_ERR(out_err);
+  return out_err;
+}
+
 u8_error_t json_element_writer_end_diagram_fake( json_element_writer_t *this_, const data_diagram_t *diag_ptr )
 {
     U8_TRACE_BEGIN();
@@ -1210,27 +1286,14 @@ u8_error_t json_element_writer_assemble_diagramelement( json_element_writer_t *t
                                                  true
                                                );
 
-        /* display_tags (flag names) + display_flags */
-        if ( data_diagramelement_get_display_flags( diagramelement_ptr ) != DATA_DIAGRAMELEMENT_FLAG_NONE )
-        {
-            const char *const tag_names
-                = json_type_name_map_get_diagramelement_tags( &((*this_).type_map),
-                                                              data_diagramelement_get_display_flags( diagramelement_ptr )
-                                                            );
-            out_err |= json_writer_write_member_enum( &((*this_).json_writer),
-                                                      6,
-                                                      JSON_CONSTANTS_KEY_DIAGRAMELEMENT_DISPLAY_FLAG_NAMES,
-                                                      tag_names,
-                                                      JSON_CONSTANTS_KEY_DIAGRAMELEMENT_DISPLAY_FLAGS,
-                                                      data_diagramelement_get_display_flags( diagramelement_ptr ),
-                                                      true
-                                                    );
-        }
-
         /* classifier_name */
         out_err |= json_writer_write_member_string( &((*this_).json_writer),
                                                     6,
+#ifdef JSON_CONSTANTS_NEW_KEYS
+                                                    JSON_CONSTANTS_KEY_DIAGRAMELEMENT_NODE_NAME,
+#else
                                                     JSON_CONSTANTS_KEY_DIAGRAMELEMENT_CLASSIFIER_NAME,
+#endif
                                                     data_classifier_get_name_const( occurrence ),
                                                     true
                                                   );
@@ -1254,6 +1317,23 @@ u8_error_t json_element_writer_assemble_diagramelement( json_element_writer_t *t
                                                     true
                                                   );
 
+        /* display_tags (flag names) + display_flags */
+        if ( data_diagramelement_get_display_flags( diagramelement_ptr ) != DATA_DIAGRAMELEMENT_FLAG_NONE )
+        {
+            const char *const tag_names
+                = json_type_name_map_get_diagramelement_tags( &((*this_).type_map),
+                                                              data_diagramelement_get_display_flags( diagramelement_ptr )
+                                                            );
+            out_err |= json_writer_write_member_enum( &((*this_).json_writer),
+                                                      6,
+                                                      JSON_CONSTANTS_KEY_DIAGRAMELEMENT_DISPLAY_FLAG_NAMES,
+                                                      tag_names,
+                                                      JSON_CONSTANTS_KEY_DIAGRAMELEMENT_DISPLAY_FLAGS,
+                                                      data_diagramelement_get_display_flags( diagramelement_ptr ),
+                                                      true
+                                                    );
+        }
+
         /* uuid */
         out_err |= json_writer_write_member_string( &((*this_).json_writer),
                                                     6,
@@ -1358,7 +1438,7 @@ u8_error_t json_element_writer_write_footer( json_element_writer_t *this_ )
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
