@@ -84,24 +84,17 @@ static inline double geometry_non_linear_scale_get_location ( const geometry_non
  *
  *  \param this_ pointer to own object attributes
  *  \param location location for which the order shall be determined
- *  \param snap_interval maximum distance from location to next point which snaps the location to the points location
+ *  \param snap_interval maximum distance from location to next point which snaps the location to the points location.
+ *                       There is no snap mechanism to the borders INT32_MIN and INT32_MAX.
  */
 static inline int32_t geometry_non_linear_scale_get_order ( const geometry_non_linear_scale_t *this_, double location, double snap_interval );
 
-/*!
- *  \brief gets the location of the closest fix point
- *
- *  \param this_ pointer to own object attributes
- *  \param location location value for which the closest fix-point location shall be determined
- */
-static inline double geometry_non_linear_scale_get_closest_fix_location ( const geometry_non_linear_scale_t *this_, double location );
-
 /*!
  *  \brief checks if the given order is on grid
  *
  *  \param this_ pointer to own object attributes
  *  \param order order value
- *  \return true if order is on grid
+ *  \return true if order is on grid; the borders INT32_MIN and INT32_MAX are not on grid.
  */
 static inline bool geometry_non_linear_scale_is_order_on_grid ( const geometry_non_linear_scale_t *this_, int32_t order );
 
@@ -127,7 +120,7 @@ static inline double geometry_non_linear_scale_get_grid_distances ( const geomet
 
 
 /*
-Copyright 2016-2025 Andreas Warnke
+Copyright 2016-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
