@@ -112,15 +112,19 @@ static inline double layout_quality_debts_conn_diag ( const layout_quality_t *th
  *  \param this_ pointer to own object attributes
  *  \param probe a partly layouted relationship
  *  \param other a completely layouted visible classifier
+ *  \param is_source other is the probe's source end (from)
  *  \param is_ancestor_of_source other is an ancestor of the probe's source end (from)
+ *  \param is_destination other is the probe's destination end (to)
  *  \param is_ancestor_of_destination other is an ancestor of the probe's destination end (to)
  *  \return 0.0 if there are no overlaps, a positive value otherwise
  */
 static inline double layout_quality_debts_conn_class ( const layout_quality_t *this_,
                                                        const geometry_connector_t *probe,
                                                        const layout_visible_classifier_t *other,
-                                                       const bool is_ancestor_of_source,
-                                                       const bool is_ancestor_of_destination
+                                                       bool is_source,
+                                                       bool is_ancestor_of_source,
+                                                       bool is_destination,
+                                                       bool is_ancestor_of_destination
                                                      );
 
 /*!
@@ -142,11 +146,17 @@ static inline double layout_quality_debts_conn_sym ( const layout_quality_t *thi
  *  \param this_ pointer to own object attributes
  *  \param probe a partly layouted relationship
  *  \param other another partly layouted relationship
+ *  \param same_type true if probe and other have the same relationship type
+ *  \param same_source true if probe and other have the same source end (from)
+ *  \param same_destination true if probe and other have the same destination end (to)
  *  \return 0.0 if there are no overlaps, a positive value otherwise
  */
 static inline double layout_quality_debts_conn_conn ( const layout_quality_t *this_,
                                                       const geometry_connector_t *probe,
-                                                      const geometry_connector_t *other
+                                                      const geometry_connector_t *other,
+                                                      bool same_type,
+                                                      bool same_source,
+                                                      bool same_destination
                                                     );
 
 /*!
@@ -210,7 +220,7 @@ static inline double layout_quality_debts_label_rel ( const layout_quality_t *th
 
 
 /*
-Copyright 2025-2025 Andreas Warnke
+Copyright 2025-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
