@@ -14,6 +14,7 @@
 #include "layout/layout_diagram.h"
 #include "geometry/geometry_rectangle.h"
 #include "draw/draw_diagram_label.h"
+#include "draw/draw_diagram_ornaments.h"
 #include "set/data_profile_part.h"
 #include "set/data_small_set.h"
 #include "set/data_visible_set.h"
@@ -31,6 +32,7 @@
 struct pencil_diagram_painter_struct {
     pencil_marker_t marker;  /*!< own instance of a marker */
     draw_diagram_label_t draw_diagram_label;  /*!< collection of draw label functions */
+    draw_diagram_ornaments_t draw_diagram_ornaments;  /*!< collection of draw ornaments functions like e.g. x-axis scale */
 };
 
 typedef struct pencil_diagram_painter_struct pencil_diagram_painter_t;
@@ -62,7 +64,7 @@ void pencil_diagram_painter_destroy( pencil_diagram_painter_t *this_ );
  *  \param font_layout structure to layout fonts
  *  \param cr a cairo drawing context
  */
-void pencil_diagram_painter_draw ( const pencil_diagram_painter_t *this_,
+void pencil_diagram_painter_draw ( pencil_diagram_painter_t *this_,
                                    const layout_diagram_t *layouted_diagram,
                                    bool mark_focused,
                                    bool mark_highlighted,
@@ -84,7 +86,7 @@ void pencil_diagram_painter_draw ( const pencil_diagram_painter_t *this_,
  *  \param font_layout structure to layout fonts
  *  \param io_layout_diagram bounds, draw_area and label_box are updated. The pointer must not be NULL.
  */
-void pencil_diagram_painter_do_layout ( const pencil_diagram_painter_t *this_,
+void pencil_diagram_painter_do_layout ( pencil_diagram_painter_t *this_,
                                         const data_diagram_t *the_diagram,
                                         const geometry_rectangle_t *diagram_bounds,
                                         const data_profile_part_t *profile,
@@ -97,7 +99,7 @@ void pencil_diagram_painter_do_layout ( const pencil_diagram_painter_t *this_,
 
 
 /*
-Copyright 2017-2025 Andreas Warnke
+Copyright 2017-2026 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
